@@ -1,4 +1,11 @@
+# Running the test with Python 2:
+# Be sure to install pytest version 4.6.4 (newer should also work)
+# Command in cppcheck directory:
 # python -m pytest addons/test/test-misra.py
+#
+# Running the test with Python 3:
+# Command in cppcheck directory:
+# PYTHONPATH=./addons python3 -m pytest addons/test/test-misra.py
 
 import pytest
 import re
@@ -49,7 +56,7 @@ def test_loadRuleTexts_mutiple_lines(checker):
     assert(checker.ruleTexts[103].text == "Multiple lines text.")
     assert(checker.ruleTexts[104].text == "Should")
     assert(checker.ruleTexts[105].text == "Should")
-    assert(checker.ruleTexts[106].text == "Should")
+    assert(checker.ruleTexts[106].text == "Can contain empty lines.")
 
 
 def test_verifyRuleTexts(checker, capsys):
