@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2016 Cppcheck team.
+ * Copyright (C) 2007-2018 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,48 +49,48 @@ public:
      * Parse given command line.
      * @return true if command line was ok, false if there was an error.
      */
-    bool ParseFromArgs(int argc, const char* const argv[]);
+    bool parseFromArgs(int argc, const char* const argv[]);
 
     /**
      * Return if user wanted to see program version.
      */
-    bool GetShowVersion() const {
-        return _showVersion;
+    bool getShowVersion() const {
+        return mShowVersion;
     }
 
     /**
      * Return if user wanted to see list of error messages.
      */
-    bool GetShowErrorMessages() const {
-        return _showErrorMessages;
+    bool getShowErrorMessages() const {
+        return mShowErrorMessages;
     }
 
     /**
      * Return the path names user gave to command line.
      */
-    const std::vector<std::string>& GetPathNames() const {
-        return _pathnames;
+    const std::vector<std::string>& getPathNames() const {
+        return mPathNames;
     }
 
     /**
      * Return if help is shown to user.
      */
-    bool GetShowHelp() const {
-        return _showHelp;
+    bool getShowHelp() const {
+        return mShowHelp;
     }
 
     /**
      * Return if we should exit after printing version, help etc.
      */
-    bool ExitAfterPrinting() const {
-        return _exitAfterPrint;
+    bool exitAfterPrinting() const {
+        return mExitAfterPrint;
     }
 
     /**
      * Return a list of paths user wants to ignore.
      */
-    const std::vector<std::string>& GetIgnoredPaths() const {
-        return _ignoredPaths;
+    const std::vector<std::string>& getIgnoredPaths() const {
+        return mIgnoredPaths;
     }
 
 protected:
@@ -98,22 +98,22 @@ protected:
     /**
      * Print help text to the console.
      */
-    static void PrintHelp();
+    static void printHelp();
 
     /**
      * Print message (to console?).
      */
-    static void PrintMessage(const std::string &message);
-    static void PrintMessage(const char* message);
+    static void printMessage(const std::string &message);
+    static void printMessage(const char* message);
 
 private:
-    std::vector<std::string> _pathnames;
-    std::vector<std::string> _ignoredPaths;
-    Settings *_settings;
-    bool _showHelp;
-    bool _showVersion;
-    bool _showErrorMessages;
-    bool _exitAfterPrint;
+    std::vector<std::string> mPathNames;
+    std::vector<std::string> mIgnoredPaths;
+    Settings *mSettings;
+    bool mShowHelp;
+    bool mShowVersion;
+    bool mShowErrorMessages;
+    bool mExitAfterPrint;
 };
 
 /// @}
