@@ -1,15 +1,17 @@
 #include <QtWidgets>
-
+#include <QShortcut>
 #include "codeeditor.h"
 
 
-Highlighter::Highlighter(QTextDocument *parent)
-    : QSyntaxHighlighter(parent)
+Highlighter::Highlighter(QTextDocument *parent,
+                         CodeEditorStyle *widgetStyle) :
+    QSyntaxHighlighter(parent),
+    mWidgetStyle(widgetStyle)
 {
     HighlightingRule rule;
 
-    mKeywordFormat.setForeground(Qt::darkBlue);
-    mKeywordFormat.setFontWeight(QFont::Bold);
+    mKeywordFormat.setForeground(mWidgetStyle->keywordColor);
+    mKeywordFormat.setFontWeight(mWidgetStyle->keywordWeight);
     QStringList keywordPatterns;
     keywordPatterns << "bool"
                     << "break"
@@ -54,31 +56,39 @@ Highlighter::Highlighter(QTextDocument *parent)
     foreach (const QString &pattern, keywordPatterns) {
         rule.pattern = QRegularExpression("\\b" + pattern + "\\b");
         rule.format = mKeywordFormat;
+        rule.ruleRole = RuleRole::Keyword;
         mHighlightingRules.append(rule);
     }
 
-    mClassFormat.setFontWeight(QFont::Bold);
-    mClassFormat.setForeground(Qt::darkMagenta);
+    mClassFormat.setForeground(mWidgetStyle->classColor);
+    mClassFormat.setFontWeight(mWidgetStyle->classWeight);
     rule.pattern = QRegularExpression("\\bQ[A-Za-z]+\\b");
     rule.format = mClassFormat;
+    rule.ruleRole = RuleRole::Class;
     mHighlightingRules.append(rule);
 
-    mQuotationFormat.setForeground(Qt::darkGreen);
+    mQuotationFormat.setForeground(mWidgetStyle->quoteColor);
+    mQuotationFormat.setFontWeight(mWidgetStyle->quoteWeight);
     rule.pattern = QRegularExpression("\".*\"");
     rule.format = mQuotationFormat;
+    rule.ruleRole = RuleRole::Quote;
     mHighlightingRules.append(rule);
 
-    mSingleLineCommentFormat.setForeground(Qt::gray);
+    mSingleLineCommentFormat.setForeground(mWidgetStyle->commentColor);
+    mSingleLineCommentFormat.setFontWeight(mWidgetStyle->commentWeight);
     rule.pattern = QRegularExpression("//[^\n]*");
     rule.format = mSingleLineCommentFormat;
+    rule.ruleRole = RuleRole::Comment;
     mHighlightingRules.append(rule);
 
     mHighlightingRulesWithSymbols = mHighlightingRules;
 
-    mMultiLineCommentFormat.setForeground(Qt::gray);
+    mMultiLineCommentFormat.setForeground(mWidgetStyle->commentColor);
+    mMultiLineCommentFormat.setFontWeight(mWidgetStyle->commentWeight);
 
-    mSymbolFormat.setForeground(Qt::red);
-    mSymbolFormat.setBackground(QColor(220,220,255));
+    mSymbolFormat.setForeground(mWidgetStyle->symbolFGColor);
+    mSymbolFormat.setBackground(mWidgetStyle->symbolBGColor);
+    mSymbolFormat.setFontWeight(mWidgetStyle->symbolWeight);
 
     mCommentStartExpression = QRegularExpression("/\\*");
     mCommentEndExpression = QRegularExpression("\\*/");
@@ -91,10 +101,35 @@ void Highlighter::setSymbols(const QStringList &symbols)
         HighlightingRule rule;
         rule.pattern = QRegularExpression("\\b" + sym + "\\b");
         rule.format = mSymbolFormat;
+        rule.ruleRole = RuleRole::Symbol;
         mHighlightingRulesWithSymbols.append(rule);
     }
 }
 
+void Highlighter::setStyle(const CodeEditorStyle &newStyle)
+{
+    mKeywordFormat.setForeground(newStyle.keywordColor);
+    mKeywordFormat.setFontWeight(newStyle.keywordWeight);
+    mClassFormat.setForeground(newStyle.classColor);
+    mClassFormat.setFontWeight(newStyle.classWeight);
+    mSingleLineCommentFormat.setForeground(newStyle.commentColor);
+    mSingleLineCommentFormat.setFontWeight(newStyle.commentWeight);
+    mMultiLineCommentFormat.setForeground(newStyle.commentColor);
+    mMultiLineCommentFormat.setFontWeight(newStyle.commentWeight);
+    mQuotationFormat.setForeground(newStyle.quoteColor);
+    mQuotationFormat.setFontWeight(newStyle.quoteWeight);
+    mSymbolFormat.setForeground(newStyle.symbolFGColor);
+    mSymbolFormat.setBackground(newStyle.symbolBGColor);
+    mSymbolFormat.setFontWeight(newStyle.symbolWeight);
+    for (HighlightingRule& rule : mHighlightingRules) {
+        applyFormat(rule);
+    }
+
+    for (HighlightingRule& rule : mHighlightingRulesWithSymbols) {
+        applyFormat(rule);
+    }
+}
+
 void Highlighter::highlightBlock(const QString &text)
 {
     foreach (const HighlightingRule &rule, mHighlightingRulesWithSymbols) {
@@ -127,21 +162,61 @@ void Highlighter::highlightBlock(const QString &text)
     }
 }
 
+void Highlighter::applyFormat(HighlightingRule &rule)
+{
+    switch (rule.ruleRole) {
+    case RuleRole::Keyword:
+        rule.format = mKeywordFormat;
+        break;
+    case RuleRole::Class:
+        rule.format = mClassFormat;
+        break;
+    case RuleRole::Comment:
+        rule.format = mSingleLineCommentFormat;
+        break;
+    case RuleRole::Quote:
+        rule.format = mQuotationFormat;
+        break;
+    case RuleRole::Symbol:
+        rule.format = mSymbolFormat;
+        break;
+    }
+}
 
-CodeEditor::CodeEditor(QWidget *parent) : QPlainTextEdit(parent)
+CodeEditor::CodeEditor(QWidget *parent) :
+    QPlainTextEdit(parent),
+    mWidgetStyle(new CodeEditorStyle(defaultStyleLight))
 {
     mLineNumberArea = new LineNumberArea(this);
-    mHighlighter = new Highlighter(this->document());
+    mHighlighter = new Highlighter(document(), mWidgetStyle);
     mErrorPosition = -1;
 
-    setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont));
+    QFont font("Monospace");
+    font.setStyleHint(QFont::TypeWriter);
+    setFont(font);
+    mLineNumberArea->setFont(font);
+
+    // set widget coloring by overriding widget style sheet
+    setObjectName("CodeEditor");
+    setStyleSheet(generateStyleString());
+
+    QShortcut *copyText = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_C),this);
+    QShortcut *allText = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_A),this);
 
     connect(this, SIGNAL(blockCountChanged(int)), this, SLOT(updateLineNumberAreaWidth(int)));
     connect(this, SIGNAL(updateRequest(QRect,int)), this, SLOT(updateLineNumberArea(QRect,int)));
+    connect(copyText, SIGNAL(activated()), this, SLOT(copy()));
+    connect(allText, SIGNAL(activated()), this, SLOT(selectAll()));
 
     updateLineNumberAreaWidth(0);
 }
 
+CodeEditor::~CodeEditor()
+{
+    // NOTE: not a Qt Object - delete manually
+    delete mWidgetStyle;
+}
+
 static int getPos(const QString &fileData, int lineNumber)
 {
     if (lineNumber <= 1)
@@ -156,6 +231,16 @@ static int getPos(const QString &fileData, int lineNumber)
     return fileData.size();
 }
 
+void CodeEditor::setStyle(const CodeEditorStyle& newStyle)
+{
+    *mWidgetStyle = newStyle;
+    // apply new styling
+    setStyleSheet(generateStyleString());
+    mHighlighter->setStyle(newStyle);
+    mHighlighter->rehighlight();
+    highlightErrorLine();
+}
+
 void CodeEditor::setError(const QString &code, int errorLine, const QStringList &symbols)
 {
     mHighlighter->setSymbols(symbols);
@@ -213,12 +298,14 @@ void CodeEditor::highlightErrorLine()
 
     QTextEdit::ExtraSelection selection;
 
-    QColor lineColor = QColor(255,220,220);
-
-    selection.format.setBackground(lineColor);
+    selection.format.setBackground(mWidgetStyle->highlightBGColor);
     selection.format.setProperty(QTextFormat::FullWidthSelection, true);
     selection.cursor = QTextCursor(document());
-    selection.cursor.setPosition(mErrorPosition);
+    if (mErrorPosition >= 0) {
+        selection.cursor.setPosition(mErrorPosition);
+    } else {
+        selection.cursor.setPosition(0);
+    }
     selection.cursor.clearSelection();
     extraSelections.append(selection);
 
@@ -228,7 +315,7 @@ void CodeEditor::highlightErrorLine()
 void CodeEditor::lineNumberAreaPaintEvent(QPaintEvent *event)
 {
     QPainter painter(mLineNumberArea);
-    painter.fillRect(event->rect(), QColor(240,240,240));
+    painter.fillRect(event->rect(), mWidgetStyle->lineNumBGColor);
 
     QTextBlock block = firstVisibleBlock();
     int blockNumber = block.blockNumber();
@@ -238,7 +325,7 @@ void CodeEditor::lineNumberAreaPaintEvent(QPaintEvent *event)
     while (block.isValid() && top <= event->rect().bottom()) {
         if (block.isVisible() && bottom >= event->rect().top()) {
             QString number = QString::number(blockNumber + 1);
-            painter.setPen(Qt::black);
+            painter.setPen(mWidgetStyle->lineNumFGColor);
             painter.drawText(0, top, mLineNumberArea->width(), fontMetrics().height(),
                              Qt::AlignRight, number);
         }
@@ -249,3 +336,19 @@ void CodeEditor::lineNumberAreaPaintEvent(QPaintEvent *event)
         ++blockNumber;
     }
 }
+
+QString CodeEditor::generateStyleString()
+{
+    QString bgcolor = QString("background:rgb(%1,%2,%3);")
+                      .arg(mWidgetStyle->widgetBGColor.red())
+                      .arg(mWidgetStyle->widgetBGColor.green())
+                      .arg(mWidgetStyle->widgetBGColor.blue());
+    QString fgcolor = QString("color:rgb(%1,%2,%3);")
+                      .arg(mWidgetStyle->widgetFGColor.red())
+                      .arg(mWidgetStyle->widgetFGColor.green())
+                      .arg(mWidgetStyle->widgetFGColor.blue());
+    QString style = QString("%1 %2")
+                    .arg(bgcolor)
+                    .arg(fgcolor);
+    return style;
+}
