@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2016 Cppcheck team.
+ * Copyright (C) 2007-2018 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 
 
 #include "common.h"
+#include <QCoreApplication>
 #include <QSettings>
 #include <QFileInfo>
 #include <QDir>
@@ -42,3 +43,26 @@ void setPath(const QString &type, const QString &value)
     QSettings settings;
     settings.setValue(type, value);
 }
+
+QString toFilterString(const QMap<QString,QString>& filters, bool addAllSupported, bool addAll)
+{
+    QStringList entries;
+
+    if (addAllSupported) {
+        entries << QCoreApplication::translate("toFilterString", "All supported files (%1)")
+                .arg(QStringList(filters.values()).join(" "));
+    }
+
+    if (addAll) {
+        entries << QCoreApplication::translate("toFilterString", "All files (%1)").arg("*.*");
+    }
+
+    // We're using the description of the filters as the map keys, the file
+    // name patterns are our values. The generated filter string list will
+    // thus be sorted alphabetically over the descriptions.
+    for (auto k: filters.keys()) {
+        entries << QString("%1 (%2)").arg(k).arg(filters.value(k));
+    }
+
+    return entries.join(";;");
+}
