@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2018 Cppcheck team.
+ * Copyright (C) 2007-2019 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -59,13 +59,8 @@
 #define SETTINGS_SHOW_PORTABILITY       "Show portability"
 
 // Standards support
-#define SETTINGS_STD_CPP03              "Platform CPP03"
-#define SETTINGS_STD_CPP11              "Platform CPP11"
-#define SETTINGS_STD_CPP14              "Platform CPP14"
-#define SETTINGS_STD_C89                "Platform C89"
-#define SETTINGS_STD_C99                "Platform C99"
-#define SETTINGS_STD_C11                "Platform C11"
-#define SETTINGS_STD_POSIX              "Platform Posix"
+#define SETTINGS_STD_CPP                "Standard CPP"
+#define SETTINGS_STD_C                  "Standard C"
 
 // Language enforcement
 #define SETTINGS_ENFORCED_LANGUAGE      "Enforced language"
@@ -114,7 +109,7 @@
  * Returns the path of specified type if not empty. Otherwise returns last check
  * path if valid or user's home directory.
  * @param type Type of path to obtain
- * @return Best path fo provided type
+ * @return Best path for provided type
  */
 QString getPath(const QString &type);
 
