@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2017 Cppcheck team.
+ * Copyright (C) 2007-2018 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -91,6 +91,11 @@ static CppcheckLibraryData::Define loadDefine(const QXmlStreamReader &xmlReader)
     return define;
 }
 
+static QString loadUndefine(const QXmlStreamReader &xmlReader)
+{
+    return xmlReader.attributes().value("name").toString();
+}
+
 static CppcheckLibraryData::Function::Arg loadFunctionArg(QXmlStreamReader &xmlReader)
 {
     CppcheckLibraryData::Function::Arg arg;
@@ -137,7 +142,7 @@ static CppcheckLibraryData::Function::Arg loadFunctionArg(QXmlStreamReader &xmlR
     return arg;
 }
 
-static CppcheckLibraryData::Function loadFunction(QXmlStreamReader &xmlReader, const QString comments)
+static CppcheckLibraryData::Function loadFunction(QXmlStreamReader &xmlReader, const QString &comments)
 {
     CppcheckLibraryData::Function function;
     function.comments = comments;
@@ -237,6 +242,8 @@ QString CppcheckLibraryData::open(QIODevice &file)
                     containers.append(loadContainer(xmlReader));
                 else if (elementName == "define")
                     defines.append(loadDefine(xmlReader));
+                else if (elementName == "undefine")
+                    undefines.append(loadUndefine(xmlReader));
                 else if (elementName == "function")
                     functions.append(loadFunction(xmlReader, comments));
                 else if (elementName == "memory" || elementName == "resource")
@@ -258,7 +265,7 @@ QString CppcheckLibraryData::open(QIODevice &file)
     return QString();
 }
 
-static void writeContainerFunctions(QXmlStreamWriter &xmlWriter, const QString name, int extra, const QList<struct CppcheckLibraryData::Container::Function> &functions)
+static void writeContainerFunctions(QXmlStreamWriter &xmlWriter, const QString &name, int extra, const QList<struct CppcheckLibraryData::Container::Function> &functions)
 {
     if (functions.isEmpty() && extra < 0)
         return;
@@ -459,6 +466,12 @@ QString CppcheckLibraryData::toString() const
         xmlWriter.writeEndElement();
     }
 
+    foreach (const QString &undef, undefines) {
+        xmlWriter.writeStartElement("undefine");
+        xmlWriter.writeAttribute("name", undef);
+        xmlWriter.writeEndElement();
+    }
+
     foreach (const Function &function, functions) {
         writeFunction(xmlWriter, function);
     }
