@@ -4,32 +4,28 @@
 #include <QRegExp>
 #include <QValidator>
 
-#define SIMPLENAME     "[_a-zA-Z][_a-zA-Z0-9]*"            // just a name
-#define SCOPENAME      SIMPLENAME "(::" SIMPLENAME ")*"    // names with optional scope
-#define NAMES          SCOPENAME "(," SCOPENAME ")*"       // names can be separated by comma
-
 LibraryAddFunctionDialog::LibraryAddFunctionDialog(QWidget *parent) :
     QDialog(parent),
-    ui(new Ui::LibraryAddFunctionDialog)
+    mUi(new Ui::LibraryAddFunctionDialog)
 {
-    ui->setupUi(this);
+    mUi->setupUi(this);
     QRegExp rx(NAMES);
     QValidator *validator = new QRegExpValidator(rx, this);
-    ui->functionName->setValidator(validator);
+    mUi->functionName->setValidator(validator);
 }
 
 LibraryAddFunctionDialog::~LibraryAddFunctionDialog()
 {
-    delete ui;
+    delete mUi;
 }
 
 QString LibraryAddFunctionDialog::functionName() const
 {
-    return ui->functionName->text();
+    return mUi->functionName->text();
 }
 
 int LibraryAddFunctionDialog::numberOfArguments() const
 {
-    return ui->numberOfArguments->value();
+    return mUi->numberOfArguments->value();
 }
 
