@@ -13,7 +13,9 @@ class LibraryEditArgDialog : public QDialog {
 
 public:
     LibraryEditArgDialog(QWidget *parent, const CppcheckLibraryData::Function::Arg &arg);
+    LibraryEditArgDialog(const LibraryEditArgDialog &) = delete;
     ~LibraryEditArgDialog();
+    LibraryEditArgDialog &operator=(const LibraryEditArgDialog &) = delete;
 
     CppcheckLibraryData::Function::Arg getArg() const;
 
@@ -21,9 +23,9 @@ private slots:
     void minsizeChanged(int);
 
 private:
-    Ui::LibraryEditArgDialog *ui;
+    Ui::LibraryEditArgDialog *mUi;
 
-    QList<CppcheckLibraryData::Function::Arg::MinSize> minsizes;
+    QList<CppcheckLibraryData::Function::Arg::MinSize> mMinSizes;
 };
 
 #endif // LIBRARYEDITARGDIALOG_H
