@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2018 Cppcheck team.
+ * Copyright (C) 2007-2019 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -76,19 +76,40 @@ ProjectFileDialog::ProjectFileDialog(ProjectFile *projectFile, QWidget *parent)
     const QString applicationFilePath = QCoreApplication::applicationFilePath();
     const QString appPath = QFileInfo(applicationFilePath).canonicalPath();
     QSettings settings;
-#ifdef CFGDIR
-    const QString cfgdir = CFGDIR;
-#endif
     const QString datadir = settings.value("DATADIR",QString()).toString();
     QStringList searchPaths;
     searchPaths << appPath << appPath + "/cfg" << inf.canonicalPath();
-#ifdef CFGDIR
-    if (!cfgdir.isEmpty())
-        searchPaths << cfgdir << cfgdir + "/cfg";
+#ifdef FILESDIR
+    if (FILESDIR[0])
+        searchPaths << FILESDIR << FILESDIR "/cfg";
 #endif
     if (!datadir.isEmpty())
         searchPaths << datadir << datadir + "/cfg";
     QStringList libs;
+    // Search the std.cfg first since other libraries could depend on it
+    QString stdLibraryFilename;
+    foreach (const QString sp, searchPaths) {
+        QDir dir(sp);
+        dir.setSorting(QDir::Name);
+        dir.setNameFilters(QStringList("*.cfg"));
+        dir.setFilter(QDir::Files | QDir::NoDotAndDotDot);
+        foreach (QFileInfo item, dir.entryInfoList()) {
+            QString library = item.fileName();
+            if (library.compare("std.cfg", Qt::CaseInsensitive) != 0)
+                continue;
+            Library lib;
+            const QString fullfilename = sp + "/" + library;
+            const Library::Error err = lib.load(nullptr, fullfilename.toLatin1());
+            if (err.errorcode != Library::OK)
+                continue;
+            // Working std.cfg found
+            stdLibraryFilename = fullfilename;
+            break;
+        }
+        if (!stdLibraryFilename.isEmpty())
+            break;
+    }
+    // Search other libraries
     foreach (const QString sp, searchPaths) {
         QDir dir(sp);
         dir.setSorting(QDir::Name);
@@ -99,7 +120,12 @@ ProjectFileDialog::ProjectFileDialog(ProjectFile *projectFile, QWidget *parent)
             {
                 Library lib;
                 const QString fullfilename = sp + "/" + library;
-                const Library::Error err = lib.load(nullptr, fullfilename.toLatin1());
+                Library::Error err = lib.load(nullptr, fullfilename.toLatin1());
+                if (err.errorcode != Library::OK) {
+                    // Some libraries depend on std.cfg so load it first and test again
+                    lib.load(nullptr, stdLibraryFilename.toLatin1());
+                    err = lib.load(nullptr, fullfilename.toLatin1());
+                }
                 if (err.errorcode != Library::OK)
                     continue;
             }
@@ -110,12 +136,12 @@ ProjectFileDialog::ProjectFileDialog(ProjectFile *projectFile, QWidget *parent)
                 libs << library;
         }
     }
-    qSort(libs);
-    foreach (const QString library, libs) {
-        QCheckBox *checkbox = new QCheckBox(this);
-        checkbox->setText(library);
-        mUI.mLayoutLibraries->addWidget(checkbox);
-        mLibraryCheckboxes << checkbox;
+    libs.sort();
+    mUI.mLibraries->clear();
+    for (const QString &lib : libs) {
+        QListWidgetItem* item = new QListWidgetItem(lib, mUI.mLibraries);
+        item->setFlags(item->flags() | Qt::ItemIsUserCheckable); // set checkable flag
+        item->setCheckState(Qt::Unchecked); // AND initialize check state
     }
 
     // Platforms..
@@ -141,7 +167,7 @@ ProjectFileDialog::ProjectFileDialog(ProjectFile *projectFile, QWidget *parent)
                 platformFiles << platformFile;
         }
     }
-    qSort(platformFiles);
+    platformFiles.sort();
     mUI.mComboBoxPlatform->addItems(platformFiles);
 
     mUI.mEditTags->setValidator(new QRegExpValidator(QRegExp("[a-zA-Z0-9 ;]*"),this));
@@ -211,6 +237,9 @@ void ProjectFileDialog::loadFromProjectFile(const ProjectFile *projectFile)
     setCheckPaths(projectFile->getCheckPaths());
     setImportProject(projectFile->getImportProject());
     mUI.mChkAllVsConfigs->setChecked(projectFile->getAnalyzeAllVsConfigs());
+    mUI.mCheckHeaders->setChecked(projectFile->getCheckHeaders());
+    mUI.mCheckUnusedTemplates->setChecked(projectFile->getCheckUnusedTemplates());
+    mUI.mMaxCtuDepth->setValue(projectFile->getMaxCtuDepth());
     setExcludedPaths(projectFile->getExcludedPaths());
     setLibraries(projectFile->getLibraries());
     const QString platform = projectFile->getPlatform();
@@ -242,6 +271,23 @@ void ProjectFileDialog::loadFromProjectFile(const ProjectFile *projectFile)
     mUI.mComboBoxPlatform->setCurrentText(projectFile->getPlatform());
     setSuppressions(projectFile->getSuppressions());
 
+    // Human knowledge..
+    /*
+    mUI.mListUnknownFunctionReturn->clear();
+    mUI.mListUnknownFunctionReturn->addItem("rand()");
+    for (int row = 0; row < mUI.mListUnknownFunctionReturn->count(); ++row) {
+        QListWidgetItem *item = mUI.mListUnknownFunctionReturn->item(row);
+        item->setFlags(item->flags() | Qt::ItemIsUserCheckable); // set checkable flag
+        const bool unknownValues = projectFile->getCheckUnknownFunctionReturn().contains(item->text());
+        item->setCheckState(unknownValues ? Qt::Checked : Qt::Unchecked); // AND initialize check state
+    }
+    mUI.mCheckSafeClasses->setChecked(projectFile->getSafeChecks().classes);
+    mUI.mCheckSafeExternalFunctions->setChecked(projectFile->getSafeChecks().externalFunctions);
+    mUI.mCheckSafeInternalFunctions->setChecked(projectFile->getSafeChecks().internalFunctions);
+    mUI.mCheckSafeExternalVariables->setChecked(projectFile->getSafeChecks().externalVariables);
+    */
+
+    // Addons..
     QSettings settings;
     const QString dataDir = settings.value("DATADIR", QString()).toString();
     updateAddonCheckBox(mUI.mAddonThreadSafety, projectFile, dataDir, "threadsafety");
@@ -275,6 +321,9 @@ void ProjectFileDialog::saveToProjectFile(ProjectFile *projectFile) const
     projectFile->setBuildDir(getBuildDir());
     projectFile->setImportProject(getImportProject());
     projectFile->setAnalyzeAllVsConfigs(mUI.mChkAllVsConfigs->isChecked());
+    projectFile->setCheckHeaders(mUI.mCheckHeaders->isChecked());
+    projectFile->setCheckUnusedTemplates(mUI.mCheckUnusedTemplates->isChecked());
+    projectFile->setMaxCtuDepth(mUI.mMaxCtuDepth->value());
     projectFile->setIncludes(getIncludePaths());
     projectFile->setDefines(getDefines());
     projectFile->setUndefines(getUndefines());
@@ -291,6 +340,23 @@ void ProjectFileDialog::saveToProjectFile(ProjectFile *projectFile) const
             projectFile->setPlatform(QString());
     }
     projectFile->setSuppressions(getSuppressions());
+    // Human knowledge
+    /*
+    QStringList unknownReturnValues;
+    for (int row = 0; row < mUI.mListUnknownFunctionReturn->count(); ++row) {
+        QListWidgetItem *item = mUI.mListUnknownFunctionReturn->item(row);
+        if (item->checkState() == Qt::Checked)
+            unknownReturnValues << item->text();
+    }
+    projectFile->setCheckUnknownFunctionReturn(unknownReturnValues);
+    ProjectFile::SafeChecks safeChecks;
+    safeChecks.classes = mUI.mCheckSafeClasses->isChecked();
+    safeChecks.externalFunctions = mUI.mCheckSafeExternalFunctions->isChecked();
+    safeChecks.internalFunctions = mUI.mCheckSafeInternalFunctions->isChecked();
+    safeChecks.externalVariables = mUI.mCheckSafeExternalVariables->isChecked();
+    projectFile->setSafeChecks(safeChecks);
+    */
+    // Addons
     QStringList list;
     if (mUI.mAddonThreadSafety->isChecked())
         list << "threadsafety";
@@ -328,7 +394,7 @@ QString ProjectFileDialog::getExistingDirectory(const QString &caption, bool tra
     // make it a relative path instead of absolute path.
     const QDir dir(rootpath);
     const QString relpath(dir.relativeFilePath(selectedDir));
-    if (!relpath.startsWith("."))
+    if (!relpath.startsWith("../.."))
         selectedDir = relpath;
 
     // Trailing slash..
@@ -470,9 +536,10 @@ QStringList ProjectFileDialog::getExcludedPaths() const
 QStringList ProjectFileDialog::getLibraries() const
 {
     QStringList libraries;
-    foreach (const QCheckBox *checkbox, mLibraryCheckboxes) {
-        if (checkbox->isChecked())
-            libraries << checkbox->text();
+    for (int row = 0; row < mUI.mLibraries->count(); ++row) {
+        QListWidgetItem *item = mUI.mLibraries->item(row);
+        if (item->checkState() == Qt::Checked)
+            libraries << item->text();
     }
     return libraries;
 }
@@ -525,9 +592,9 @@ void ProjectFileDialog::setExcludedPaths(const QStringList &paths)
 
 void ProjectFileDialog::setLibraries(const QStringList &libraries)
 {
-    for (int i = 0; i < mLibraryCheckboxes.size(); i++) {
-        QCheckBox *checkbox = mLibraryCheckboxes[i];
-        checkbox->setChecked(libraries.contains(checkbox->text()));
+    for (int row = 0; row < mUI.mLibraries->count(); ++row) {
+        QListWidgetItem *item = mUI.mLibraries->item(row);
+        item->setCheckState(libraries.contains(item->text()) ? Qt::Checked : Qt::Unchecked);
     }
 }
 
