@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2017 Cppcheck team.
+ * Copyright (C) 2007-2018 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +32,6 @@
 */
 class Report : public QObject {
 public:
-
     enum Type {
         TXT,
         XMLV2,
@@ -57,7 +56,7 @@ public:
     /**
     * @brief Close the report (file).
     */
-    virtual void close();
+    void close();
 
     /**
     * @brief Write report header.
