@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2017 Cppcheck team.
+ * Copyright (C) 2007-2019 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ class ThreadHandler;
 class ResultsTree : public QTreeView {
     Q_OBJECT
 public:
-    explicit ResultsTree(QWidget * parent = 0);
+    explicit ResultsTree(QWidget * parent = nullptr);
     virtual ~ResultsTree();
     void initialize(QSettings *settings, ApplicationList *list, ThreadHandler *checkThreadHandler);
 
@@ -198,7 +198,7 @@ signals:
     *
     * @param current Model index to specify new selected item.
     */
-    void selectionChanged(const QModelIndex &current);
+    void treeSelectionChanged(const QModelIndex &current);
 
     /**
      * Selected item(s) has been tagged
@@ -252,28 +252,9 @@ protected slots:
     void context(int application);
 
     /**
-    * @brief Slot for context menu item to copy filename to clipboard
-    *
+    * @brief Slot for context menu item to copy selection to clipboard
     */
-    void copyFilename();
-
-    /**
-    * @brief Slot for context menu item to copy full path to clipboard
-    *
-    */
-    void copyFullPath();
-
-    /**
-    * @brief Slot for context menu item to the current error message to clipboard
-    *
-    */
-    void copyMessage();
-
-    /**
-    * @brief Slot for context menu item to the current error message Id to clipboard
-    *
-    */
-    void copyMessageId();
+    void copy();
 
     /**
     * @brief Slot for context menu item to hide the current error message
@@ -545,6 +526,8 @@ private:
 
     QStringList mTags;
 
+    QStringList mHiddenMessageId;
+
     QItemSelectionModel *mSelectionModel;
     ThreadHandler *mThread;
 
