@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2018 Cppcheck team.
+ * Copyright (C) 2007-2019 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,6 +28,8 @@
 #include "applicationdialog.h"
 #include "applicationlist.h"
 #include "translationhandler.h"
+#include "codeeditorstyle.h"
+#include "codeeditstyledialog.h"
 #include "common.h"
 
 SettingsDialog::SettingsDialog(ApplicationList *list,
@@ -64,6 +66,9 @@ SettingsDialog::SettingsDialog(ApplicationList *list,
 #else
     mUI.mTabClang->setVisible(false);
 #endif
+    mCurrentStyle = new CodeEditorStyle(CodeEditorStyle::loadSettings(&settings));
+    manageStyleControls();
+
     connect(mUI.mButtons, &QDialogButtonBox::accepted, this, &SettingsDialog::ok);
     connect(mUI.mButtons, &QDialogButtonBox::rejected, this, &SettingsDialog::reject);
     connect(mUI.mBtnAddApplication, SIGNAL(clicked()),
@@ -79,6 +84,11 @@ SettingsDialog::SettingsDialog(ApplicationList *list,
 
     connect(mUI.mBtnBrowsePythonPath, &QPushButton::clicked, this, &SettingsDialog::browsePythonPath);
     connect(mUI.mBtnBrowseMisraFile, &QPushButton::clicked, this, &SettingsDialog::browseMisraFile);
+    connect(mUI.mBtnEditTheme, SIGNAL(clicked()), this, SLOT(editCodeEditorStyle()));
+    connect(mUI.mThemeSystem, SIGNAL(released()), this, SLOT(setCodeEditorStyleDefault()));
+    connect(mUI.mThemeDark, SIGNAL(released()), this, SLOT(setCodeEditorStyleDefault()));
+    connect(mUI.mThemeLight, SIGNAL(released()), this, SLOT(setCodeEditorStyleDefault()));
+    connect(mUI.mThemeCustom, SIGNAL(toggled(bool)), mUI.mBtnEditTheme, SLOT(setEnabled(bool)));
 
     mUI.mListWidget->setSortingEnabled(false);
     populateApplicationList();
@@ -175,6 +185,7 @@ void SettingsDialog::saveSettingValues() const
         const QString langcode = currentLang->data(mLangCodeRole).toString();
         settings.setValue(SETTINGS_LANGUAGE, langcode);
     }
+    CodeEditorStyle::saveSettings(&settings, *mCurrentStyle);
 }
 
 void SettingsDialog::saveCheckboxValue(QSettings *settings, QCheckBox *box,
@@ -215,7 +226,7 @@ void SettingsDialog::removeApplication()
 void SettingsDialog::editApplication()
 {
     QList<QListWidgetItem *> selected = mUI.mListWidget->selectedItems();
-    QListWidgetItem *item = 0;
+    QListWidgetItem *item = nullptr;
     foreach (item, selected) {
         int row = mUI.mListWidget->row(item);
         Application& app = mTempApplications->getApplication(row);
@@ -316,6 +327,29 @@ void SettingsDialog::browseMisraFile()
         mUI.mEditMisraFile->setText(fileName);
 }
 
+// Slot to set default light style
+void SettingsDialog::setCodeEditorStyleDefault()
+{
+    if (mUI.mThemeSystem->isChecked())
+        *mCurrentStyle = CodeEditorStyle::getSystemTheme();
+    if (mUI.mThemeLight->isChecked())
+        *mCurrentStyle = defaultStyleLight;
+    if (mUI.mThemeDark->isChecked())
+        *mCurrentStyle = defaultStyleDark;
+    manageStyleControls();
+}
+
+// Slot to edit custom style
+void SettingsDialog::editCodeEditorStyle()
+{
+    StyleEditDialog dlg(*mCurrentStyle, this);
+    int nResult = dlg.exec();
+    if (nResult == QDialog::Accepted) {
+        *mCurrentStyle = dlg.getStyle();
+        manageStyleControls();
+    }
+}
+
 void SettingsDialog::browseClangPath()
 {
     QString selectedDir = QFileDialog::getExistingDirectory(this,
@@ -326,3 +360,16 @@ void SettingsDialog::browseClangPath()
         mUI.mEditClangPath->setText(selectedDir);
     }
 }
+
+void SettingsDialog::manageStyleControls()
+{
+    bool isSystemTheme = mCurrentStyle->isSystemTheme();
+    bool isDefaultLight = !isSystemTheme && *mCurrentStyle == defaultStyleLight;
+    bool isDefaultDark =  !isSystemTheme && *mCurrentStyle == defaultStyleDark;
+    mUI.mThemeSystem->setChecked(isSystemTheme);
+    mUI.mThemeLight->setChecked(isDefaultLight && !isDefaultDark);
+    mUI.mThemeDark->setChecked(!isDefaultLight && isDefaultDark);
+    mUI.mThemeCustom->setChecked(!isSystemTheme && !isDefaultLight && !isDefaultDark);
+    mUI.mBtnEditTheme->setEnabled(!isSystemTheme && !isDefaultLight && !isDefaultDark);
+}
+
