@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2017 Cppcheck team.
+ * Copyright (C) 2007-2018 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -72,8 +72,8 @@ public:
     /**
     * ErrorLogger methods
     */
-    void reportOut(const std::string &outmsg);
-    void reportErr(const ErrorLogger::ErrorMessage &msg);
+    void reportOut(const std::string &outmsg) override;
+    void reportErr(const ErrorLogger::ErrorMessage &msg) override;
 
 public slots:
 
