@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2016 Cppcheck team.
+ * Copyright (C) 2007-2019 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 // Provide own translations for standard buttons. This (garbage) code is needed to enforce them to appear in .ts files even after "lupdate gui.pro"
 static void unused()
 {
+// NOTE: Keeping semi-colons at end of macro for style preference
 #if ((QT_VERSION >= 0x040000)&&(QT_VERSION < 0x050000))
     Q_UNUSED(QT_TRANSLATE_NOOP("QDialogButtonBox", "OK"));
     Q_UNUSED(QT_TRANSLATE_NOOP("QDialogButtonBox", "Cancel"));
@@ -47,7 +48,7 @@ static void unused()
 TranslationHandler::TranslationHandler(QObject *parent) :
     QObject(parent),
     mCurrentLanguage("en"),
-    mTranslator(NULL)
+    mTranslator(nullptr)
 {
     // Add our available languages
     // Keep this list sorted
@@ -90,7 +91,7 @@ bool TranslationHandler::setLanguage(const QString &code)
         if (mTranslator) {
             qApp->removeTranslator(mTranslator);
             delete mTranslator;
-            mTranslator = NULL;
+            mTranslator = nullptr;
         }
 
         mCurrentLanguage = code;
@@ -102,42 +103,42 @@ bool TranslationHandler::setLanguage(const QString &code)
     if (index == -1) {
         error = QObject::tr("Unknown language specified!");
         failure = true;
-    }
+    } else {
+        // Make sure there is a translator
+        if (!mTranslator && !failure)
+            mTranslator = new QTranslator(this);
 
-    // Make sure there is a translator
-    if (!mTranslator && !failure)
-        mTranslator = new QTranslator(this);
+        //Load the new language
+        const QString appPath = QFileInfo(QCoreApplication::applicationFilePath()).canonicalPath();
 
-    //Load the new language
-    const QString appPath = QFileInfo(QCoreApplication::applicationFilePath()).canonicalPath();
+        QSettings settings;
+        QString datadir = settings.value("DATADIR").toString();
+        if (datadir.isEmpty())
+            datadir = appPath;
 
-    QSettings settings;
-    QString datadir = settings.value("DATADIR").toString();
-    if (datadir.isEmpty())
-        datadir = appPath;
+        QString translationFile;
+        if (QFile::exists(datadir + "/lang/" + mTranslations[index].mFilename + ".qm"))
+            translationFile = datadir + "/lang/" + mTranslations[index].mFilename + ".qm";
 
-    QString translationFile;
-    if (QFile::exists(datadir + "/lang/" + mTranslations[index].mFilename + ".qm"))
-        translationFile = datadir + "/lang/" + mTranslations[index].mFilename + ".qm";
+        else if (QFile::exists(datadir + "/" + mTranslations[index].mFilename + ".qm"))
+            translationFile = datadir + "/" + mTranslations[index].mFilename + ".qm";
 
-    else if (QFile::exists(datadir + "/" + mTranslations[index].mFilename + ".qm"))
-        translationFile = datadir + "/" + mTranslations[index].mFilename + ".qm";
+        else
+            translationFile = appPath + "/" + mTranslations[index].mFilename + ".qm";
 
-    else
-        translationFile = appPath + "/" + mTranslations[index].mFilename + ".qm";
+        if (!mTranslator->load(translationFile) && !failure) {
+            //If it failed, lets check if the default file exists
+            if (!QFile::exists(translationFile)) {
+                error = QObject::tr("Language file %1 not found!");
+                error = error.arg(translationFile);
+                failure = true;
+            }
 
-    if (!mTranslator->load(translationFile) && !failure) {
-        //If it failed, lets check if the default file exists
-        if (!QFile::exists(translationFile)) {
-            error = QObject::tr("Language file %1 not found!");
+            //If file exists, there's something wrong with it
+            error = QObject::tr("Failed to load translation for language %1 from file %2");
+            error = error.arg(mTranslations[index].mName);
             error = error.arg(translationFile);
-            failure = true;
         }
-
-        //If file exists, there's something wrong with it
-        error = QObject::tr("Failed to load translation for language %1 from file %2");
-        error = error.arg(mTranslations[index].mName);
-        error = error.arg(translationFile);
     }
 
     if (failure) {
