@@ -1,6 +1,6 @@
 /*
 * Cppcheck - A tool for static C/C++ code analysis
-* Copyright (C) 2007-2016 Cppcheck team.
+* Copyright (C) 2007-2018 Cppcheck team.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -58,8 +58,8 @@ public:
     void setFileInfo(const std::string &check, const std::string &fileInfo);
     static std::string getAnalyzerInfoFile(const std::string &buildDir, const std::string &sourcefile, const std::string &cfg);
 private:
-    std::ofstream fout;
-    std::string analyzerInfoFile;
+    std::ofstream mOutputStream;
+    std::string mAnalyzerInfoFile;
 };
 
 /// @}
