@@ -67,6 +67,8 @@ bool astIsBool(const Token *tok);
 
 bool astIsPointer(const Token *tok);
 
+bool astIsSmartPointer(const Token* tok);
+
 bool astIsIterator(const Token *tok);
 
 bool astIsContainer(const Token *tok);
@@ -85,13 +87,19 @@ std::string astCanonicalType(const Token *expr);
 /** Is given syntax tree a variable comparison against value */
 const Token * astIsVariableComparison(const Token *tok, const std::string &comp, const std::string &rhs, const Token **vartok=nullptr);
 
+bool isTemporary(bool cpp, const Token* tok, const Library* library);
+
 const Token * nextAfterAstRightmostLeaf(const Token * tok);
 
 Token* astParentSkipParens(Token* tok);
 const Token* astParentSkipParens(const Token* tok);
 
+const Token* getParentMember(const Token * tok);
+
 bool precedes(const Token * tok1, const Token * tok2);
 
+bool exprDependsOnThis(const Token* expr, nonneg int depth = 0);
+
 bool isSameExpression(bool cpp, bool macro, const Token *tok1, const Token *tok2, const Library& library, bool pure, bool followVar, ErrorPath* errors=nullptr);
 
 bool isEqualKnownValue(const Token * const tok1, const Token * const tok2);
@@ -118,7 +126,10 @@ bool isWithoutSideEffects(bool cpp, const Token* tok);
 bool isUniqueExpression(const Token* tok);
 
 /** Is scope a return scope (scope will unconditionally return) */
-bool isReturnScope(const Token *endToken, const Settings * settings = nullptr, bool functionScope=false);
+bool isReturnScope(const Token * const endToken, const Library * library=nullptr, bool functionScope=false);
+
+/// Return the token to the function and the argument number
+const Token * getTokenArgumentFunction(const Token * tok, int& argn);
 
 /** Is variable changed by function call?
  * In case the answer of the question is inconclusive, e.g. because the function declaration is not known
@@ -148,9 +159,19 @@ bool isVariableChanged(const Token *tok, int indirect, const Settings *settings,
 
 bool isVariableChanged(const Variable * var, const Settings *settings, bool cpp, int depth = 20);
 
+bool isVariablesChanged(const Token* start,
+                        const Token* end,
+                        int indirect,
+                        std::vector<const Variable*> vars,
+                        const Settings* settings,
+                        bool cpp);
+
 const Token* findVariableChanged(const Token *start, const Token *end, int indirect, const nonneg int varid, bool globalvar, const Settings *settings, bool cpp, int depth = 20);
 Token* findVariableChanged(Token *start, const Token *end, int indirect, const nonneg int varid, bool globalvar, const Settings *settings, bool cpp, int depth = 20);
 
+/// If token is an alias if another variable
+bool isAliasOf(const Token *tok, nonneg int varid);
+
 bool isAliased(const Variable *var);
 
 /** Determines the number of arguments - if token is a function call or macro
@@ -188,61 +209,7 @@ bool isConstVarExpression(const Token *tok);
 
 const Variable *getLHSVariable(const Token *tok);
 
-struct PathAnalysis {
-    enum class Progress {
-        Continue,
-        Break
-    };
-    PathAnalysis(const Token* start, const Library& library)
-        : start(start), library(&library)
-    {}
-    const Token * start;
-    const Library * library;
-
-    struct Info {
-        const Token* tok;
-        ErrorPath errorPath;
-        bool known;
-    };
-
-    void forward(const std::function<Progress(const Info&)>& f) const;
-    template<class F>
-    void forwardAll(F f) {
-        forward([&](const Info& info) {
-            f(info);
-            return Progress::Continue;
-        });
-    }
-    template<class Predicate>
-    Info forwardFind(Predicate pred) {
-        Info result{};
-        forward([&](const Info& info) {
-            if (pred(info)) {
-                result = info;
-                return Progress::Break;
-            }
-            return Progress::Continue;
-        });
-        return result;
-    }
-private:
-
-    Progress forwardRecursive(const Token* tok, Info info, const std::function<PathAnalysis::Progress(const Info&)>& f) const;
-    Progress forwardRange(const Token* startToken, const Token* endToken, Info info, const std::function<Progress(const Info&)>& f) const;
-
-    static const Scope* findOuterScope(const Scope * scope);
-
-    static std::pair<bool, bool> checkCond(const Token * tok, bool& known);
-};
-
-/**
- * @brief Returns true if there is a path between the two tokens
- *
- * @param start Starting point of the path
- * @param dest The path destination
- * @param errorPath Adds the path traversal to the errorPath
- */
-bool reaches(const Token * start, const Token * dest, const Library& library, ErrorPath* errorPath);
+bool isScopeBracket(const Token* tok);
 
 /**
  * Forward data flow analysis for checks
@@ -284,6 +251,8 @@ public:
     /** Is there some possible alias for given expression */
     bool possiblyAliased(const Token *expr, const Token *startToken) const;
 
+    std::set<int> getExprVarIds(const Token* expr, bool* localOut = nullptr, bool* unknownVarIdOut = nullptr) const;
+
     static bool isNullOperand(const Token *expr);
 private:
     static bool isEscapedAlias(const Token* expr);
@@ -297,7 +266,7 @@ private:
     };
 
     struct Result check(const Token *expr, const Token *startToken, const Token *endToken);
-    struct Result checkRecursive(const Token *expr, const Token *startToken, const Token *endToken, const std::set<int> &exprVarIds, bool local, bool inInnerClass);
+    struct Result checkRecursive(const Token *expr, const Token *startToken, const Token *endToken, const std::set<int> &exprVarIds, bool local, bool inInnerClass, int depth=0);
 
     // Is expression a l-value global data?
     bool isGlobalData(const Token *expr) const;
