@@ -57,10 +57,8 @@ void CheckBool::checkIncrementBoolean()
     const SymbolDatabase *symbolDatabase = mTokenizer->getSymbolDatabase();
     for (const Scope * scope : symbolDatabase->functionScopes) {
         for (const Token* tok = scope->bodyStart->next(); tok != scope->bodyEnd; tok = tok->next()) {
-            if (Token::Match(tok, "%var% ++")) {
-                const Variable *var = tok->variable();
-                if (isBool(var))
-                    incrementBooleanError(tok);
+            if (astIsBool(tok) && tok->astParent() && tok->astParent()->str() == "++") {
+                incrementBooleanError(tok);
             }
         }
     }
@@ -95,27 +93,22 @@ void CheckBool::checkBitwiseOnBoolean()
     const SymbolDatabase *symbolDatabase = mTokenizer->getSymbolDatabase();
     for (const Scope * scope : symbolDatabase->functionScopes) {
         for (const Token* tok = scope->bodyStart->next(); tok != scope->bodyEnd; tok = tok->next()) {
-            if (Token::Match(tok, "(|.|return|&&|%oror%|throw|, %var% [&|]")) {
-                const Variable *var = tok->next()->variable();
-                if (isBool(var)) {
-                    bitwiseOnBooleanError(tok->next(), var->name(), tok->strAt(2) == "&" ? "&&" : "||");
-                    tok = tok->tokAt(2);
-                }
-            } else if (Token::Match(tok, "[&|] %var% )|.|return|&&|%oror%|throw|,") && (!tok->previous() || !tok->previous()->isExtendedOp() || tok->strAt(-1) == ")" || tok->strAt(-1) == "]")) {
-                const Variable *var = tok->next()->variable();
-                if (isBool(var)) {
-                    bitwiseOnBooleanError(tok->next(), var->name(), tok->str() == "&" ? "&&" : "||");
-                    tok = tok->tokAt(2);
+            if (tok->isBinaryOp() && (tok->str() == "&" || tok->str() == "|")) {
+                if (astIsBool(tok->astOperand1()) || astIsBool(tok->astOperand2())) {
+                    if (tok->astOperand2()->variable() && tok->astOperand2()->variable()->nameToken() == tok->astOperand2())
+                        continue;
+                    const std::string expression = astIsBool(tok->astOperand1()) ? tok->astOperand1()->expressionString() : tok->astOperand2()->expressionString();
+                    bitwiseOnBooleanError(tok, expression, tok->str() == "&" ? "&&" : "||");
                 }
             }
         }
     }
 }
 
-void CheckBool::bitwiseOnBooleanError(const Token *tok, const std::string &varname, const std::string &op)
+void CheckBool::bitwiseOnBooleanError(const Token *tok, const std::string &expression, const std::string &op)
 {
     reportError(tok, Severity::style, "bitwiseOnBoolean",
-                "Boolean variable '" + varname + "' is used in bitwise operation. Did you mean '" + op + "'?",
+                "Boolean expression '" + expression + "' is used in bitwise operation. Did you mean '" + op + "'?",
                 CWE398,
                 true);
 }
@@ -289,16 +282,9 @@ void CheckBool::checkAssignBoolToPointer()
     const SymbolDatabase *symbolDatabase = mTokenizer->getSymbolDatabase();
     for (const Scope * scope : symbolDatabase->functionScopes) {
         for (const Token* tok = scope->bodyStart; tok != scope->bodyEnd; tok = tok->next()) {
-            if (tok->str() != "=")
-                continue;
-            const ValueType *lhsType = tok->astOperand1() ? tok->astOperand1()->valueType() : nullptr;
-            if (!lhsType || lhsType->pointer == 0)
-                continue;
-            const ValueType *rhsType = tok->astOperand2() ? tok->astOperand2()->valueType() : nullptr;
-            if (!rhsType || rhsType->pointer > 0 || rhsType->type != ValueType::Type::BOOL)
-                continue;
-
-            assignBoolToPointerError(tok);
+            if (tok->str() == "=" && astIsPointer(tok->astOperand1()) && astIsBool(tok->astOperand2())) {
+                assignBoolToPointerError(tok);
+            }
         }
     }
 }
@@ -436,15 +422,8 @@ void CheckBool::checkAssignBoolToFloat()
     const SymbolDatabase *symbolDatabase = mTokenizer->getSymbolDatabase();
     for (const Scope * scope : symbolDatabase->functionScopes) {
         for (const Token* tok = scope->bodyStart; tok != scope->bodyEnd; tok = tok->next()) {
-            if (tok->str() == "=" && astIsBool(tok->astOperand2())) {
-                const Token *lhs = tok->astOperand1();
-                while (lhs && (lhs->str() == "." || lhs->str() == "::"))
-                    lhs = lhs->astOperand2();
-                if (!lhs || !lhs->variable())
-                    continue;
-                const Variable* var = lhs->variable();
-                if (var && var->isFloatingType() && !var->isArrayOrPointer())
-                    assignBoolToFloatError(tok->next());
+            if (tok->str() == "=" && astIsFloat(tok->astOperand1(), false) && astIsBool(tok->astOperand2())) {
+                assignBoolToFloatError(tok);
             }
         }
     }
@@ -456,7 +435,7 @@ void CheckBool::assignBoolToFloatError(const Token *tok)
                 "Boolean value assigned to floating point variable.", CWE704, false);
 }
 
-void CheckBool::returnValueOfFunctionReturningBool(void)
+void CheckBool::returnValueOfFunctionReturningBool()
 {
     if (!mSettings->isEnabled(Settings::STYLE))
         return;
