@@ -188,10 +188,7 @@ static bool getDimensionsEtc(const Token * const arrayToken, const Settings *set
     while (Token::Match(array, ".|::"))
         array = array->astOperand2();
 
-    if (!array->variable())
-        return false;
-
-    if (array->variable()->isArray() && !array->variable()->dimensions().empty()) {
+    if (array->variable() && array->variable()->isArray() && !array->variable()->dimensions().empty()) {
         *dimensions = array->variable()->dimensions();
         if (dimensions->size() >= 1 && ((*dimensions)[0].num <= 1 || !(*dimensions)[0].tok)) {
             visitAstNodes(arrayToken,
@@ -203,10 +200,10 @@ static bool getDimensionsEtc(const Token * const arrayToken, const Settings *set
                 return ChildrenToVisit::op1_and_op2;
             });
         }
-    } else if (const Token *stringLiteral = array->getValueTokenMinStrSize()) {
+    } else if (const Token *stringLiteral = array->getValueTokenMinStrSize(settings)) {
         Dimension dim;
         dim.tok = nullptr;
-        dim.num = Token::getStrSize(stringLiteral);
+        dim.num = Token::getStrArraySize(stringLiteral);
         dim.known = array->hasKnownValue();
         dimensions->emplace_back(dim);
     } else if (array->valueType() && array->valueType()->pointer >= 1 && array->valueType()->isIntegral()) {
@@ -244,7 +241,7 @@ static std::vector<const ValueFlow::Value *> getOverrunIndexValues(const Token *
                     continue;
                 allKnown = false;
             }
-            if (array->variable()->isArray() && dimensions[i].num == 0)
+            if (array->variable() && array->variable()->isArray() && dimensions[i].num == 0)
                 continue;
             if (value->intvalue == dimensions[i].num)
                 equal = true;
@@ -275,7 +272,7 @@ void CheckBufferOverrun::arrayIndex()
         const Token *array = tok->astOperand1();
         while (Token::Match(array, ".|::"))
             array = array->astOperand2();
-        if (!array|| !array->variable() || array->variable()->nameToken() == array)
+        if (!array || ((!array->variable() || array->variable()->nameToken() == array) && array->tokType() != Token::eString))
             continue;
         if (!array->scope()->isExecutable()) {
             // LHS in non-executable scope => This is just a definition
@@ -286,6 +283,9 @@ void CheckBufferOverrun::arrayIndex()
                 continue;
         }
 
+        if (astIsContainer(array))
+            continue;
+
         std::vector<const Token *> indexTokens;
         for (const Token *tok2 = tok; tok2 && tok2->str() == "["; tok2 = tok2->link()->next()) {
             if (!tok2->astOperand2()) {
@@ -313,8 +313,8 @@ void CheckBufferOverrun::arrayIndex()
         // Negative index
         bool neg = false;
         std::vector<const ValueFlow::Value *> negativeIndexes;
-        for (int i = 0; i < indexTokens.size(); ++i) {
-            const ValueFlow::Value *negativeValue = indexTokens[i]->getValueLE(-1, mSettings);
+        for (const Token * indexToken : indexTokens) {
+            const ValueFlow::Value *negativeValue = indexToken->getValueLE(-1, mSettings);
             negativeIndexes.emplace_back(negativeValue);
             if (negativeValue)
                 neg = true;
@@ -588,6 +588,8 @@ void CheckBufferOverrun::bufferOverflow()
                     argtok = argtok->astOperand2();
                 if (!argtok || !argtok->variable())
                     continue;
+                if (argtok->valueType() && argtok->valueType()->pointer == 0)
+                    continue;
                 // TODO: strcpy(buf+10, "hello");
                 const ValueFlow::Value bufferSize = getBufferSize(argtok);
                 if (bufferSize.intvalue <= 1)
@@ -631,7 +633,7 @@ void CheckBufferOverrun::arrayIndexThenCheck()
                 // Iterate AST upwards
                 const Token* tok2 = tok;
                 const Token* tok3 = tok2;
-                while (tok2->astParent() && tok2->tokType() != Token::eLogicalOp) {
+                while (tok2->astParent() && tok2->tokType() != Token::eLogicalOp && tok2->str() != "?") {
                     tok3 = tok2;
                     tok2 = tok2->astParent();
                 }
