@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2018 Cppcheck team.
+ * Copyright (C) 2007-2019 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -94,13 +94,18 @@ void CheckInternal::checkRedundantTokCheck()
             // the first tok->previous() check is redundant
             const Token *astOp1 = tok->astOperand1();
             const Token *astOp2 = getArguments(tok->tokAt(3))[0];
-
+            if (Token::simpleMatch(astOp1, "&&")) {
+                astOp1 = astOp1->astOperand2();
+            }
             if (astOp1->expressionString() == astOp2->expressionString()) {
                 checkRedundantTokCheckError(astOp2);
             }
             // if (!tok || !Token::match(tok, "foo"))
         } else if (Token::Match(tok, "%oror% ! Token :: simpleMatch|Match|findsimplematch|findmatch (")) {
             const Token *negTok = tok->next()->astParent()->astOperand1();
+            if (Token::simpleMatch(negTok, "||")) {
+                negTok = negTok->astOperand2();
+            }
             // the first tok condition is negated
             if (Token::simpleMatch(negTok, "!")) {
                 const Token *astOp1 = negTok->astOperand1();
@@ -353,7 +358,7 @@ void CheckInternal::checkStlUsage()
     for (const Scope *scope : symbolDatabase->functionScopes) {
         for (const Token* tok = scope->bodyStart->next(); tok != scope->bodyEnd; tok = tok->next()) {
             if (Token::simpleMatch(tok, ". emplace ("))
-                reportError(tok, Severity::error, "internalStlUsage", "The 'emplace' function shall be avoided for now. 'emplace_back' is fine");
+                reportError(tok, Severity::error, "internalStlUsage", "The 'emplace' function shall be avoided for now. It is not available e.g. in Slackware 14.0. 'emplace_back' is fine.");
             //if (Token::simpleMatch(tok, ". back ( )") && tok->astOperand1() && tok->astOperand1()->valueType() && tok->astOperand1()->valueType()->container && Token::simpleMatch(tok->astOperand1()->valueType()->container, "std :: string"))
             //  reportError(tok, Severity::error, "internalStlUsage", "The 'std::string::back()' function shall be avoided for now.");
         }
