@@ -102,26 +102,23 @@ public:
      * @param varid variable id
      * @return type of deallocation
      */
-    AllocType getDeallocationType(const Token *tok, unsigned int varid) const;
+    AllocType getDeallocationType(const Token *tok, nonneg int varid) const;
 
     /**
      * @brief Get type of allocation at given position
      */
-    AllocType getAllocationType(const Token *tok2, unsigned int varid, std::list<const Function*> *callstack = nullptr) const;
+    AllocType getAllocationType(const Token *tok2, nonneg int varid, std::list<const Function*> *callstack = nullptr) const;
 
     /**
      * @brief Get type of reallocation at given position
      */
-    static AllocType getReallocationType(const Token *tok2, unsigned int varid);
+    AllocType getReallocationType(const Token *tok2, nonneg int varid) const;
 
     /**
-     * @brief Is a typename the name of a class?
-     * @param tok type token
-     * @param varid variable id
-     * @return true if the type name is the name of a class
+     * Check if token reopens a standard stream
+     * @param tok token to check
      */
-    bool isclass(const Token *tok, unsigned int varid) const;
-
+    bool isReopenStandardStream(const Token *tok) const;
     /**
      * Report that there is a memory leak (new/malloc/etc)
      * @param tok token where memory is leaked
@@ -145,13 +142,13 @@ public:
     void deallocuseError(const Token *tok, const std::string &varname) const;
     void mismatchSizeError(const Token *tok, const std::string &sz) const;
     void mismatchAllocDealloc(const std::list<const Token *> &callstack, const std::string &varname) const;
-    void memleakUponReallocFailureError(const Token *tok, const std::string &varname) const;
+    void memleakUponReallocFailureError(const Token *tok, const std::string &reallocfunction, const std::string &varname) const;
 
     /** What type of allocated memory does the given function return? */
     AllocType functionReturnType(const Function* func, std::list<const Function*> *callstack = nullptr) const;
 
     /** Function allocates pointed-to argument (a la asprintf)? */
-    const char *functionArgAlloc(const Function *func, unsigned int targetpar, AllocType &allocType) const;
+    const char *functionArgAlloc(const Function *func, nonneg int targetpar, AllocType &allocType) const;
 };
 
 /// @}
@@ -209,7 +206,7 @@ private:
         c.mismatchSizeError(nullptr, "sz");
         const std::list<const Token *> callstack;
         c.mismatchAllocDealloc(callstack, "varname");
-        c.memleakUponReallocFailureError(nullptr, "varname");
+        c.memleakUponReallocFailureError(nullptr, "realloc", "varname");
     }
 
     /**
@@ -338,6 +335,13 @@ public:
     void check();
 
 private:
+    /**
+     * @brief %Check if an input argument to a function is the return value of an allocation function
+     * like malloc(), and the function does not release it.
+     * @param scope     The scope of the function to check.
+     */
+    void checkForUnreleasedInputArgument(const Scope *scope);
+
     /**
      * @brief %Check if a call to an allocation function like malloc() is made and its return value is not assigned.
      * @param scope     The scope of the function to check.
