@@ -219,7 +219,7 @@ private:
     void clarifyCalculationError(const Token *tok, const std::string &op);
     void clarifyStatementError(const Token* tok);
     void cstyleCastError(const Token *tok);
-    void invalidPointerCastError(const Token* tok, const std::string& from, const std::string& to, bool inconclusive);
+    void invalidPointerCastError(const Token* tok, const std::string& from, const std::string& to, bool inconclusive, bool toIsInt);
     void passedByValueError(const Token *tok, const std::string &parname, bool inconclusive);
     void constVariableError(const Variable *var);
     void constStatementError(const Token *tok, const std::string &type, bool inconclusive);
@@ -250,7 +250,7 @@ private:
     void pointerLessThanZeroError(const Token *tok, const ValueFlow::Value *v);
     void unsignedPositiveError(const Token *tok, const ValueFlow::Value *v, const std::string &varname);
     void pointerPositiveError(const Token *tok, const ValueFlow::Value *v);
-    void SuspiciousSemicolonError(const Token *tok);
+    void suspiciousSemicolonError(const Token *tok);
     void negativeBitwiseShiftError(const Token *tok, int op);
     void redundantCopyError(const Token *tok, const std::string &varname);
     void incompleteArrayFillError(const Token* tok, const std::string& buffer, const std::string& function, bool boolean);
@@ -276,7 +276,7 @@ private:
         // error
         c.zerodivError(nullptr, nullptr);
         c.misusedScopeObjectError(nullptr, "varname");
-        c.invalidPointerCastError(nullptr,  "float", "double", false);
+        c.invalidPointerCastError(nullptr,  "float *", "double *", false, false);
         c.negativeBitwiseShiftError(nullptr, 1);
         c.negativeBitwiseShiftError(nullptr, 2);
         c.checkPipeParameterSizeError(nullptr,  "varname", "dimension");
@@ -316,7 +316,7 @@ private:
         c.unsignedPositiveError(nullptr, nullptr, "varname");
         c.pointerLessThanZeroError(nullptr, nullptr);
         c.pointerPositiveError(nullptr, nullptr);
-        c.SuspiciousSemicolonError(nullptr);
+        c.suspiciousSemicolonError(nullptr);
         c.incompleteArrayFillError(nullptr,  "buffer", "memset", false);
         c.varFuncNullUBError(nullptr);
         c.nanInArithmeticExpressionError(nullptr);
