@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2018 Cppcheck team.
+ * Copyright (C) 2007-2019 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -300,8 +300,17 @@ void CheckSizeof::sizeofCalculation()
         }
 
         const Token *argument = tok->next()->astOperand2();
-        if (argument && argument->isCalculation() && (!argument->isExpandedMacro() || printInconclusive))
-            sizeofCalculationError(argument, argument->isExpandedMacro());
+        if (!argument || !argument->isCalculation())
+            continue;
+
+        bool inconclusive = false;
+        if (argument->isExpandedMacro())
+            inconclusive = true;
+        else if (tok->next()->isExpandedMacro())
+            inconclusive = true;
+
+        if (!inconclusive || printInconclusive)
+            sizeofCalculationError(argument, inconclusive);
     }
 }
 
