@@ -60,7 +60,7 @@ void CheckString::stringLiteralWrite()
         for (const Token* tok = scope->bodyStart->next(); tok != scope->bodyEnd; tok = tok->next()) {
             if (!tok->variable() || !tok->variable()->isPointer())
                 continue;
-            const Token *str = tok->getValueTokenMinStrSize();
+            const Token *str = tok->getValueTokenMinStrSize(mSettings);
             if (!str)
                 continue;
             if (Token::Match(tok, "%var% [") && Token::simpleMatch(tok->linkAt(1), "] ="))
@@ -80,10 +80,11 @@ void CheckString::stringLiteralWriteError(const Token *tok, const Token *strValu
 
     std::string errmsg("Modifying string literal");
     if (strValue) {
-        std::string s = strValue->strValue();
-        if (s.size() > 15U)
-            s = s.substr(0,13) + "..";
-        errmsg += " \"" + s + "\"";
+        std::string s = strValue->str();
+        // 20 is an arbitrary value, the max string length shown in a warning message
+        if (s.size() > 20U)
+            s = s.substr(0,17) + "..\"";
+        errmsg += " " + s;
     }
     errmsg += " directly or indirectly is undefined behaviour.";
 
@@ -184,8 +185,7 @@ void CheckString::checkSuspiciousStringCompare()
             // Pointer addition?
             if (varTok->str() == "+" && mTokenizer->isC()) {
                 const Token * const tokens[2] = { varTok->astOperand1(), varTok->astOperand2() };
-                for (int nr = 0; nr < 2; nr++) {
-                    const Token *t = tokens[nr];
+                for (const Token * t : tokens) {
                     while (t && (t->str() == "." || t->str() == "::"))
                         t = t->astOperand2();
                     if (t && t->variable() && t->variable()->isPointer())
@@ -328,9 +328,9 @@ void CheckString::incorrectStringCompareError(const Token *tok, const std::strin
 
 void CheckString::incorrectStringBooleanError(const Token *tok, const std::string& string)
 {
-    const bool charLiteral = string[0] == '\'';
+    const bool charLiteral = isCharLiteral(string);
     const std::string literalType = charLiteral ? "char" : "string";
-    const std::string result = (string == "\'\\0\'") ? "false" : "true";
+    const std::string result = getCharLiteral(string) == "\\0" ? "false" : "true";
     reportError(tok,
                 Severity::warning,
                 charLiteral ? "incorrectCharBooleanError" : "incorrectStringBooleanError",
