@@ -32,6 +32,8 @@
 #include "tokenlist.h"
 #include "version.h"
 
+#include "exprengine.h"
+
 #define PICOJSON_USE_INT64
 #include <picojson.h>
 #include <simplecpp.h>
@@ -44,6 +46,7 @@
 #include <vector>
 #include <memory>
 #include <iostream> // <- TEMPORARY
+#include <cstdio>
 
 #ifdef HAVE_RULES
 #define PCRE_STATIC
@@ -53,7 +56,7 @@
 static const char Version[] = CPPCHECK_VERSION_STRING;
 static const char ExtraVersion[] = "";
 
-static TimerResults S_timerResults;
+static TimerResults s_timerResults;
 
 // CWE ids used
 static const CWE CWE398(398U);  // Indicator of Poor Code Quality
@@ -113,6 +116,10 @@ namespace {
                 return "Failed to open " + fileName;
             picojson::value json;
             fin >> json;
+            std::string json_error = picojson::get_last_error();
+            if (!json_error.empty()) {
+                return "Loading " + fileName + " failed. " + json_error;
+            }
             if (!json.is<picojson::object>())
                 return "Loading " + fileName + " failed. Bad json.";
             picojson::object obj = json.get<picojson::object>();
@@ -130,7 +137,26 @@ namespace {
 
 static std::string executeAddon(const AddonInfo &addonInfo, const std::string &dumpFile)
 {
-    const std::string cmd = "python \"" + addonInfo.scriptFile + "\" --cli" + addonInfo.args + " \"" + dumpFile + "\"";
+    // Can python be executed?
+    {
+        const std::string cmd = "python --version 2>&1";
+
+#ifdef _WIN32
+        std::unique_ptr<FILE, decltype(&_pclose)> pipe(_popen(cmd.c_str(), "r"), _pclose);
+#else
+        std::unique_ptr<FILE, decltype(&pclose)> pipe(popen(cmd.c_str(), "r"), pclose);
+#endif
+        if (!pipe)
+            throw InternalError(nullptr, "popen failed (command: '" + cmd + "')");
+        char buffer[1024];
+        std::string result;
+        while (fgets(buffer, sizeof(buffer), pipe.get()) != nullptr)
+            result += buffer;
+        if (result.compare(0, 7, "Python ", 0, 7) != 0 || result.size() > 50)
+            throw InternalError(nullptr, "Failed to execute '" + cmd + "' (" + result + ")");
+    }
+
+    const std::string cmd = "python \"" + addonInfo.scriptFile + "\" --cli" + addonInfo.args + " \"" + dumpFile + "\" 2>&1";
 
 #ifdef _WIN32
     std::unique_ptr<FILE, decltype(&_pclose)> pipe(_popen(cmd.c_str(), "r"), _pclose);
@@ -138,12 +164,22 @@ static std::string executeAddon(const AddonInfo &addonInfo, const std::string &d
     std::unique_ptr<FILE, decltype(&pclose)> pipe(popen(cmd.c_str(), "r"), pclose);
 #endif
     if (!pipe)
-        return "";
+        throw InternalError(nullptr, "popen failed (command: '" + cmd + "')");
     char buffer[1024];
     std::string result;
     while (fgets(buffer, sizeof(buffer), pipe.get()) != nullptr) {
         result += buffer;
     }
+
+    // Validate output..
+    std::istringstream istr(result);
+    std::string line;
+    while (std::getline(istr, line)) {
+        if (line.compare(0,9,"Checking ", 0, 9) != 0 && !line.empty() && line[0] != '{')
+            throw InternalError(nullptr, "Failed to execute '" + cmd + "'. " + result);
+    }
+
+    // Valid results
     return result;
 }
 
@@ -171,7 +207,7 @@ CppCheck::~CppCheck()
         delete mFileInfo.back();
         mFileInfo.pop_back();
     }
-    S_timerResults.ShowResults(mSettings.showtime);
+    s_timerResults.showResults(mSettings.showtime);
 }
 
 const char * CppCheck::version()
@@ -221,7 +257,7 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
     if (!Path::acceptFile(filename))
         mSettings.debugwarnings = false;
 
-    if (mSettings.terminated())
+    if (Settings::terminated())
         return mExitCode;
 
     if (!mSettings.quiet) {
@@ -269,6 +305,7 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
             case simplecpp::Output::INCLUDE_NESTED_TOO_DEEPLY:
             case simplecpp::Output::SYNTAX_ERROR:
             case simplecpp::Output::UNHANDLED_CHAR_ERROR:
+            case simplecpp::Output::EXPLICIT_INCLUDE_NOT_FOUND:
                 err = true;
                 break;
             case simplecpp::Output::WARNING:
@@ -276,7 +313,7 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
             case simplecpp::Output::PORTABILITY_BACKSLASH:
                 err = false;
                 break;
-            };
+            }
 
             if (err) {
                 const ErrorLogger::ErrorMessage::FileLocation loc1(output.location.file(), output.location.line, output.location.col);
@@ -293,7 +330,8 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
             }
         }
 
-        preprocessor.loadFiles(tokens1, files);
+        if (!preprocessor.loadFiles(tokens1, files))
+            return mExitCode;
 
         if (!mSettings.plistOutput.empty()) {
             std::string filename2;
@@ -384,8 +422,8 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
         preprocessor.setPlatformInfo(&tokens1);
 
         // Get configurations..
-        if (mSettings.userDefines.empty() || mSettings.force) {
-            Timer t("Preprocessor::getConfigs", mSettings.showtime, &S_timerResults);
+        if ((mSettings.checkAllConfigurations && mSettings.userDefines.empty()) || mSettings.force) {
+            Timer t("Preprocessor::getConfigs", mSettings.showtime, &s_timerResults);
             configurations = preprocessor.getConfigs(tokens1);
         } else {
             configurations.insert(mSettings.userDefines);
@@ -430,7 +468,7 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
         std::list<std::string> configurationError;
         for (const std::string &currCfg : configurations) {
             // bail out if terminated
-            if (mSettings.terminated())
+            if (Settings::terminated())
                 break;
 
             // Check only a few configurations (default 12), after that bail out, unless --force
@@ -451,9 +489,9 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
             }
 
             if (mSettings.preprocessOnly) {
-                Timer t("Preprocessor::getcode", mSettings.showtime, &S_timerResults);
+                Timer t("Preprocessor::getcode", mSettings.showtime, &s_timerResults);
                 std::string codeWithoutCfg = preprocessor.getcode(tokens1, mCurrentConfig, files, true);
-                t.Stop();
+                t.stop();
 
                 if (codeWithoutCfg.compare(0,5,"#file") == 0)
                     codeWithoutCfg.insert(0U, "//");
@@ -472,16 +510,16 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
 
             Tokenizer mTokenizer(&mSettings, this);
             if (mSettings.showtime != SHOWTIME_MODES::SHOWTIME_NONE)
-                mTokenizer.setTimerResults(&S_timerResults);
+                mTokenizer.setTimerResults(&s_timerResults);
 
             try {
                 bool result;
 
                 // Create tokens, skip rest of iteration if failed
-                Timer timer("Tokenizer::createTokens", mSettings.showtime, &S_timerResults);
+                Timer timer("Tokenizer::createTokens", mSettings.showtime, &s_timerResults);
                 const simplecpp::TokenList &tokensP = preprocessor.preprocess(tokens1, mCurrentConfig, files, true);
                 mTokenizer.createTokens(&tokensP);
-                timer.Stop();
+                timer.stop();
                 hasValidConfig = true;
 
                 // If only errors are printed, print filename after the check
@@ -502,9 +540,9 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
                 checkRawTokens(mTokenizer);
 
                 // Simplify tokens into normal form, skip rest of iteration if failed
-                Timer timer2("Tokenizer::simplifyTokens1", mSettings.showtime, &S_timerResults);
+                Timer timer2("Tokenizer::simplifyTokens1", mSettings.showtime, &s_timerResults);
                 result = mTokenizer.simplifyTokens1(mCurrentConfig);
-                timer2.Stop();
+                timer2.stop();
                 if (!result)
                     continue;
 
@@ -541,13 +579,13 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
                 // simplify more if required, skip rest of iteration if failed
                 if (mSimplify && hasRule("simple")) {
                     // if further simplification fails then skip rest of iteration
-                    Timer timer3("Tokenizer::simplifyTokenList2", mSettings.showtime, &S_timerResults);
+                    Timer timer3("Tokenizer::simplifyTokenList2", mSettings.showtime, &s_timerResults);
                     result = mTokenizer.simplifyTokenList2();
-                    timer3.Stop();
+                    timer3.stop();
                     if (!result)
                         continue;
 
-                    if (!mSettings.terminated())
+                    if (!Settings::terminated())
                         executeRules("simple", mTokenizer);
                 }
 
@@ -612,6 +650,7 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
                 const std::string &failedToGetAddonInfo = addonInfo.getAddonInfo(addon, mSettings.exename);
                 if (!failedToGetAddonInfo.empty()) {
                     reportOut(failedToGetAddonInfo);
+                    mExitCode = 1;
                     continue;
                 }
                 const std::string results = executeAddon(addonInfo, dumpFile);
@@ -650,6 +689,7 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
                     reportErr(errmsg);
                 }
             }
+            std::remove(dumpFile.c_str());
         }
 
     } catch (const std::runtime_error &e) {
@@ -715,16 +755,21 @@ void CppCheck::checkNormalTokens(const Tokenizer &tokenizer)
 {
     // call all "runChecks" in all registered Check classes
     for (Check *check : Check::instances()) {
-        if (mSettings.terminated())
+        if (Settings::terminated())
             return;
 
-        if (tokenizer.isMaxTime())
+        if (Tokenizer::isMaxTime())
             return;
 
-        Timer timerRunChecks(check->name() + "::runChecks", mSettings.showtime, &S_timerResults);
+        Timer timerRunChecks(check->name() + "::runChecks", mSettings.showtime, &s_timerResults);
         check->runChecks(&tokenizer, &mSettings, this);
     }
 
+    // Verification using ExprEngine..
+    if (mSettings.verification) {
+        ExprEngine::runChecks(this, &tokenizer, &mSettings);
+    }
+
     // Analyse the tokens..
 
     CTU::FileInfo *fi1 = CTU::getFileInfo(&tokenizer);
