@@ -564,7 +564,7 @@ bool ErrorLogger::reportUnmatchedSuppressions(const std::list<Suppressions::Supp
         bool suppressed = false;
         for (const Suppressions::Suppression &s2 : unmatched) {
             if (s2.errorId == "unmatchedSuppression") {
-                if ((s2.fileName == "*" || s2.fileName == s.fileName) &&
+                if ((s2.fileName.empty() || s2.fileName == "*" || s2.fileName == s.fileName) &&
                     (s2.lineNumber == Suppressions::Suppression::NO_LINE || s2.lineNumber == s.lineNumber)) {
                     suppressed = true;
                     break;
@@ -638,8 +638,7 @@ std::string ErrorLogger::ErrorMessage::FileLocation::stringify() const
 std::string ErrorLogger::toxml(const std::string &str)
 {
     std::ostringstream xml;
-    for (std::size_t i = 0U; i < str.length(); i++) {
-        const unsigned char c = str[i];
+    for (unsigned char c : str) {
         switch (c) {
         case '<':
             xml << "&lt;";
@@ -678,8 +677,8 @@ std::string ErrorLogger::plistHeader(const std::string &version, const std::vect
          << "<string>cppcheck version " << version << "</string>\r\n"
          << " <key>files</key>\r\n"
          << " <array>\r\n";
-    for (unsigned int i = 0; i < files.size(); ++i)
-        ostr << "  <string>" << ErrorLogger::toxml(files[i]) << "</string>\r\n";
+    for (const std::string & file : files)
+        ostr << "  <string>" << ErrorLogger::toxml(file) << "</string>\r\n";
     ostr       << " </array>\r\n"
                << " <key>diagnostics</key>\r\n"
                << " <array>\r\n";
