@@ -30,6 +30,7 @@
 #include "suppressions.h"
 #include "timer.h"
 
+#include <atomic>
 #include <list>
 #include <set>
 #include <string>
@@ -65,7 +66,7 @@ private:
     int mEnabled;
 
     /** @brief terminate checking */
-    static bool mTerminated;
+    static std::atomic<bool> mTerminated;
 
 public:
     Settings();
@@ -187,6 +188,11 @@ public:
 
     SafeChecks safeChecks;
 
+    /** @brief Enable verification analysis */
+    bool verification;
+
+    bool debugVerification;
+
     /** @brief check unknown function return values */
     std::set<std::string> checkUnknownFunctionReturn;
 
@@ -215,6 +221,9 @@ public:
         Default is 12. (--max-configs=N) */
     unsigned int maxConfigs;
 
+    /** @brief --check all configurations */
+    bool checkAllConfigurations;
+
     /** @brief --max-ctu-depth */
     int maxCtuDepth;
 
@@ -302,8 +311,8 @@ public:
      * @return true for the file to be excluded.
      */
     bool configurationExcluded(const std::string &file) const {
-        for (std::set<std::string>::const_iterator i=configExcludePaths.begin(); i!=configExcludePaths.end(); ++i) {
-            if (file.length()>=i->length() && file.compare(0,i->length(),*i)==0) {
+        for (const std::string & configExcludePath : configExcludePaths) {
+            if (file.length()>=configExcludePath.length() && file.compare(0,configExcludePath.length(),configExcludePath)==0) {
                 return true;
             }
         }
