@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2018 Cppcheck team.
+ * Copyright (C) 2007-2019 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -74,6 +74,8 @@ std::string Suppressions::parseFile(std::istream &istr)
             continue;
 
         // Skip comments
+        if (line.length() > 1 && line[0] == '#')
+            continue;
         if (line.length() >= 2 && line[0] == '/' && line[1] == '/')
             continue;
 
@@ -304,7 +306,7 @@ bool Suppressions::isSuppressedLocal(const Suppressions::ErrorMessage &errmsg)
     return false;
 }
 
-void Suppressions::dump(std::ostream & out)
+void Suppressions::dump(std::ostream & out) const
 {
     out << "  <suppressions>" << std::endl;
     for (const Suppression &suppression : mSuppressions) {
