@@ -148,7 +148,7 @@ public:
      * @brief Create an xml dump of suppressions
      * @param out stream to write XML to
     */
-    void dump(std::ostream &out);
+    void dump(std::ostream &out) const;
 
     /**
      * @brief Returns list of unmatched local (per-file) suppressions.
