@@ -107,7 +107,7 @@ public:
      * \param unknown set to true if it's unknown if the scope is noreturn
      * \return true if scope ends with a function call that might be 'noreturn'
      */
-    bool IsScopeNoReturn(const Token *endScopeToken, bool *unknown = nullptr) const;
+    bool isScopeNoReturn(const Token *endScopeToken, bool *unknown = nullptr) const;
 
     bool createTokens(std::istream &code, const std::string& FileName);
     void createTokens(const simplecpp::TokenList *tokenList);
@@ -154,8 +154,6 @@ public:
     */
     bool simplifyTokenList1(const char FileName[]);
 
-    void SimplifyNamelessRValueReferences();
-
     /**
     * Most aggressive simplification of tokenlist
     *
@@ -250,6 +248,8 @@ public:
     /** Remove macros in global scope */
     void removeMacrosInGlobalScope();
 
+    void addSemicolonAfterUnknownMacro();
+
     /** Remove undefined macro in class definition:
       * class DLLEXPORT Fred { };
       * class Fred FINAL : Base { };
@@ -376,6 +376,10 @@ public:
      */
     void simplifyTypedef();
 
+    /**
+     */
+    bool isMemberFunction(const Token *openParen) const;
+
     /**
      */
     bool simplifyUsing();
@@ -793,6 +797,8 @@ private:
     /** Find end of SQL (or PL/SQL) block */
     static const Token *findSQLBlockEnd(const Token *tokSQLStart);
 
+    bool operatorEnd(const Token * tok) const;
+
 public:
 
     /** Was there templates in the code? */
@@ -884,13 +890,13 @@ public:
 
     void calculateScopes();
 
-private:
     /** Disable copy constructor */
     Tokenizer(const Tokenizer &) = delete;
 
     /** Disable assignment operator */
     Tokenizer &operator=(const Tokenizer &) = delete;
 
+private:
     Token *processFunc(Token *tok2, bool inOperator) const;
 
     /**
