@@ -27,15 +27,29 @@
 #include <list>
 #include <string>
 #include <utility>
+#include <vector>
 
 class ErrorLogger;
 class Settings;
 class SymbolDatabase;
 class Token;
 class TokenList;
+class ValueType;
 class Variable;
 
 namespace ValueFlow {
+    struct increment {
+        template <class T>
+        void operator()(T& x) const {
+            x++;
+        }
+    };
+    struct decrement {
+        template <class T>
+        void operator()(T& x) const {
+            x--;
+        }
+    };
     class CPPCHECKLIB Value {
     public:
         typedef std::pair<const Token *, std::string> ErrorPathItem;
@@ -43,6 +57,7 @@ namespace ValueFlow {
 
         explicit Value(long long val = 0)
             : valueType(ValueType::INT),
+              bound(Bound::Point),
               intvalue(val),
               tokvalue(nullptr),
               floatValue(0.0),
@@ -60,7 +75,7 @@ namespace ValueFlow {
         {}
         Value(const Token *c, long long val);
 
-        bool operator==(const Value &rhs) const {
+        bool equalValue(const ValueFlow::Value& rhs) const {
             if (valueType != rhs.valueType)
                 return false;
             switch (valueType) {
@@ -95,6 +110,33 @@ namespace ValueFlow {
                 if (tokvalue != rhs.tokvalue)
                     return false;
             }
+            return true;
+        }
+
+        template <class F>
+        void visitValue(F f) {
+            switch (valueType) {
+            case ValueType::INT:
+            case ValueType::BUFFER_SIZE:
+            case ValueType::CONTAINER_SIZE: {
+                f(intvalue);
+                break;
+            }
+            case ValueType::FLOAT: {
+                f(floatValue);
+                break;
+            }
+            case ValueType::UNINIT:
+            case ValueType::TOK:
+            case ValueType::LIFETIME:
+            case ValueType::MOVED:
+                break;
+            }
+        }
+
+        bool operator==(const Value &rhs) const {
+            if (!equalValue(rhs))
+                return false;
 
             return varvalue == rhs.varvalue &&
                    condition == rhs.condition &&
@@ -105,6 +147,25 @@ namespace ValueFlow {
                    valueKind == rhs.valueKind;
         }
 
+        bool operator!=(const Value &rhs) const {
+            return !(*this == rhs);
+        }
+
+        void decreaseRange() {
+            if (bound == Bound::Lower)
+                visitValue(increment{});
+            else if (bound == Bound::Upper)
+                visitValue(decrement{});
+        }
+
+        void invertRange() {
+            if (bound == Bound::Lower)
+                bound = Bound::Upper;
+            else if (bound == Bound::Upper)
+                bound = Bound::Lower;
+            decreaseRange();
+        }
+
         std::string infoString() const;
 
         enum ValueType { INT, TOK, FLOAT, MOVED, UNINIT, CONTAINER_SIZE, LIFETIME, BUFFER_SIZE } valueType;
@@ -145,6 +206,9 @@ namespace ValueFlow {
             return isMovedValue() || isUninitValue() || isLifetimeValue();
         }
 
+        /** The value bound  */
+        enum class Bound { Upper, Lower, Point } bound;
+
         /** int value */
         long long intvalue;
 
@@ -202,7 +266,9 @@ namespace ValueFlow {
             /** Only listed values are possible */
             Known,
             /** Inconclusive */
-            Inconclusive
+            Inconclusive,
+            /** Listed values are impossible */
+            Impossible
         } valueKind;
 
         void setKnown() {
@@ -221,6 +287,14 @@ namespace ValueFlow {
             return valueKind == ValueKind::Possible;
         }
 
+        bool isImpossible() const {
+            return valueKind == ValueKind::Impossible;
+        }
+
+        void setImpossible() {
+            valueKind = ValueKind::Impossible;
+        }
+
         void setInconclusive(bool inconclusive = true) {
             if (inconclusive)
                 valueKind = ValueKind::Inconclusive;
@@ -247,9 +321,44 @@ namespace ValueFlow {
     void setValues(TokenList *tokenlist, SymbolDatabase* symboldatabase, ErrorLogger *errorLogger, const Settings *settings);
 
     std::string eitherTheConditionIsRedundant(const Token *condition);
+
+    size_t getSizeOf(const ValueType &vt, const Settings *settings);
 }
 
-const Variable *getLifetimeVariable(const Token *tok, ValueFlow::Value::ErrorPath &errorPath);
+struct LifetimeToken {
+    const Token* token;
+    bool addressOf;
+    ValueFlow::Value::ErrorPath errorPath;
+    bool inconclusive;
+
+    LifetimeToken() : token(nullptr), addressOf(false), errorPath(), inconclusive(false) {}
+
+    LifetimeToken(const Token* token, ValueFlow::Value::ErrorPath errorPath)
+        : token(token), addressOf(false), errorPath(std::move(errorPath)), inconclusive(false)
+    {}
+
+    LifetimeToken(const Token* token, bool addressOf, ValueFlow::Value::ErrorPath errorPath)
+        : token(token), addressOf(addressOf), errorPath(std::move(errorPath)), inconclusive(false)
+    {}
+
+    static std::vector<LifetimeToken> setAddressOf(std::vector<LifetimeToken> v, bool b) {
+        for (LifetimeToken& x : v)
+            x.addressOf = b;
+        return v;
+    }
+
+    static std::vector<LifetimeToken> setInconclusive(std::vector<LifetimeToken> v, bool b) {
+        for (LifetimeToken& x : v)
+            x.inconclusive = b;
+        return v;
+    }
+};
+
+const Token *parseCompareInt(const Token *tok, ValueFlow::Value &true_value, ValueFlow::Value &false_value);
+
+std::vector<LifetimeToken> getLifetimeTokens(const Token* tok, ValueFlow::Value::ErrorPath errorPath = ValueFlow::Value::ErrorPath{}, int depth = 20);
+
+const Variable* getLifetimeVariable(const Token* tok, ValueFlow::Value::ErrorPath& errorPath, bool* addressOf = nullptr);
 
 bool isLifetimeBorrowed(const Token *tok, const Settings *settings);
 
