@@ -9,6 +9,7 @@
 
 #define PY_SSIZE_T_CLEAN
 #include <Python.h> // should be the first include
+#include <stdio.h>
 
 void validCode(PyObject * pPyObjArg)
 {
@@ -23,6 +24,11 @@ void validCode(PyObject * pPyObjArg)
     Py_CLEAR(pPyObjArg);
     Py_CLEAR(pPyObjNULL);
     (void)PyErr_NewException("text", NULL, NULL);
+
+    char * pBuf1 = PyMem_Malloc(5);
+    PyMem_Free(pBuf1);
+    int * pIntBuf1 = PyMem_New(int, 10);
+    PyMem_Free(pIntBuf1);
 }
 
 void nullPointer()
@@ -32,3 +38,24 @@ void nullPointer()
     // cppcheck-suppress nullPointer
     Py_DECREF(NULL);
 }
+
+void PyMem_Malloc_memleak()
+{
+    char * pBuf1 = PyMem_Malloc(1);
+    printf("%p", pBuf1);
+    // cppcheck-suppress memleak
+}
+
+void PyMem_Malloc_mismatchAllocDealloc()
+{
+    char * pBuf1 = PyMem_Malloc(10);
+    // cppcheck-suppress mismatchAllocDealloc
+    free(pBuf1);
+}
+
+void PyMem_New_memleak()
+{
+    char * pBuf1 = PyMem_New(char, 5);
+    printf("%p", pBuf1);
+    // cppcheck-suppress memleak
+}
