@@ -47,6 +47,7 @@ void bufferAccessOutOfBounds(void)
     // cppcheck-suppress bufferAccessOutOfBounds
     strcpy_s(a, 10, "abcdefghij");
     // TODO cppcheck-suppress redundantCopy
+    // cppcheck-suppress terminateStrncpy
     strncpy(a,"abcde",5);
     // cppcheck-suppress bufferAccessOutOfBounds
     // TODO cppcheck-suppress redundantCopy
@@ -346,6 +347,26 @@ void nullPointer_wmemcmp(wchar_t *p)
     (void)wmemcmp(p, 0, 123);
 }
 
+void nullPointer_vsnprintf(const char * format, ...)
+{
+    va_list args;
+    // valid
+    char buffer[256];
+    va_start(args, format);
+    vsnprintf(buffer, 256, format, args);
+    printf("%s", buffer);
+    va_end(args);
+    // valid
+    va_start(args, format);
+    vsnprintf(NULL, 0, format, args);
+    va_end(args);
+    // invalid
+    va_start(args, format);
+    // TODO #9410 cppcheck-suppress nullPointer
+    vsnprintf(NULL, 10, format, args);
+    va_end(args);
+}
+
 // uninit pointers
 
 void uninitvar_abs(void)
@@ -1621,23 +1642,41 @@ void uninitvar_mbsinit(void)
     (void)mbsinit(ps);
 }
 
-void uninitvar_mbstowcs(void)
+void uninitvar_mbstowcs(wchar_t* d, const char* s, size_t m)
 {
-    wchar_t *ws;
-    char *s;
-    size_t n;
+    wchar_t *dest;
+    char *src;
+    size_t max;
+
     // cppcheck-suppress uninitvar
-    (void)mbstowcs(ws,s,n);
+    (void)mbstowcs(dest,s,m);
+    // cppcheck-suppress uninitvar
+    (void)mbstowcs(d,src,m);
+    // cppcheck-suppress uninitvar
+    (void)mbstowcs(d,s,max);
+
+    // No warning is expected
+    (void)mbstowcs(d,s,m);
 }
 
-void uninitvar_mbsrtowcs(void)
+void uninitvar_mbsrtowcs(wchar_t* d, const char** s, size_t m, mbstate_t *p)
 {
     wchar_t* dest;
     const char* src;
     size_t max;
     mbstate_t* ps;
+
     // cppcheck-suppress uninitvar
-    (void)mbsrtowcs(dest,&src,max,ps);
+    (void)mbsrtowcs(dest,s,m,p);
+    // cppcheck-suppress uninitvar
+    (void)mbsrtowcs(d,&src,m,p);
+    // cppcheck-suppress uninitvar
+    (void)mbsrtowcs(d,s,max,p);
+    // cppcheck-suppress uninitvar
+    (void)mbsrtowcs(d,s,m,ps);
+
+    // No warning is expected
+    (void)mbsrtowcs(d,s,m,p);
 }
 
 void uninitvar_wctob(void)
@@ -2858,6 +2897,10 @@ void uninitvar_scanf(void)
     char str[42];
     // cppcheck-suppress uninitvar
     (void)scanf(format, str);
+
+    // no warning is expected (#9347)
+    int i;
+    sscanf("0", "%d", &i);
 }
 
 void uninitvar_vsscanf(void)
@@ -2998,46 +3041,85 @@ void uninitvar_wcschr(void)
     (void)wcschr(cs,c);
 }
 
-void uninitvar_strcmp(void)
+void uninitvar_strcmp(char *s1, char *s2)
 {
     char *str1;
     char *str2;
+
+    // cppcheck-suppress uninitvar
+    (void)strcmp(str1,s2);
+    // cppcheck-suppress uninitvar
+    (void)strcmp(s1,str2);
     // cppcheck-suppress uninitvar
     (void)strcmp(str1,str2);
+
+    // No warning is expected
+    (void)strcmp(s1,s2);
 }
 
-void uninitvar_wcscmp(void)
+void uninitvar_wcscmp(wchar_t *s1, wchar_t *s2)
 {
     wchar_t *str1;
     wchar_t *str2;
+
+    // cppcheck-suppress uninitvar
+    (void)wcscmp(str1,s2);
+    // cppcheck-suppress uninitvar
+    (void)wcscmp(s1,str2);
     // cppcheck-suppress uninitvar
     (void)wcscmp(str1,str2);
+
+    // No warning is expected
+    (void)wcscmp(s1,s2);
 }
 
-void uninitvar_strcpy(void)
+void uninitvar_strcpy(char *d, char *s)
 {
-    char *str1;
-    char *str2;
+    char *dest;
+    char *src;
+
     // cppcheck-suppress uninitvar
-    (void)strcpy(str1,str2);
+    (void)strcpy(dest,s);
+    // cppcheck-suppress uninitvar
+    (void)strcpy(d,src);
+    // cppcheck-suppress uninitvar
+    (void)strcpy(dest,src);
+
+    // No warning is expected
+    (void)strcpy(d,s);
 }
 
-void uninitvar_strcpy_s(char * strDest)
+void uninitvar_strcpy_s(char * strDest, ssize_t s, char *source)
 {
     char *strUninit1;
     char *strUninit2;
+    ssize_t  size;
+
     // cppcheck-suppress uninitvar
     (void)strcpy_s(strUninit1, 1, "a");
     // cppcheck-suppress uninitvar
     (void)strcpy_s(strDest, 1, strUninit2);
+    // cppcheck-suppress uninitvar
+    (void)strcpy_s(strDest, size, "a");
+
+    // No warning is expected
+    (void)strcpy_s(strDest, s, source);
 }
 
-void uninitvar_wcscpy(void)
+void uninitvar_wcscpy(wchar_t *d, wchar_t*s)
 {
-    wchar_t *str1;
-    wchar_t *str2;
+    wchar_t *dest;
+    wchar_t *src;
+
     // cppcheck-suppress uninitvar
-    (void)wcscpy(str1,str2);
+    (void)wcscpy(dest,s);
+    // cppcheck-suppress uninitvar
+    (void)wcscpy(d,src);
+    // cppcheck-suppress uninitvar
+    (void)wcscpy(dest,src);
+
+    // No warning is expected
+    (void)wcscpy(d,s);
 }
 
 void uninitvar_strftime(void)
@@ -3054,11 +3136,19 @@ void uninitvar_strftime(void)
     (void)strfxtime(s,max,fmt,px);
 }
 
-void uninitvar_strlen(void)
+void uninitvar_strlen(const char *str)
 {
     char *s;
     // cppcheck-suppress uninitvar
     (void)strlen(s);
+
+    const char x;
+    const char *xPtr = &x;
+    // cppcheck-suppress uninitvar
+    (void)strlen(xPtr);
+
+    // No warning is expected
+    (void)strlen(str);
 }
 
 void uninitvar_wcslen(void)
@@ -3068,13 +3158,22 @@ void uninitvar_wcslen(void)
     (void)wcslen(s);
 }
 
-void uninitvar_strncpy(void)
+//char * strncpy ( char * destination, const char * source, size_t num );
+void uninitvar_strncpy(char * dest, const char * src, size_t num)
 {
+    char *d;
     char *s;
-    char *ct;
     size_t n;
+
     // cppcheck-suppress uninitvar
-    (void)strncpy(s,ct,n);
+    (void)strncpy(d,src,num);
+    // cppcheck-suppress uninitvar
+    (void)strncpy(dest,s,num);
+    // cppcheck-suppress uninitvar
+    (void)strncpy(dest,src,n);
+
+    // No warning is expected for
+    (void)strncpy(dest,src,num);
 }
 
 void uninitvar_strncpy_s(char *Ct, size_t N1, char *S, size_t N2)
@@ -3108,22 +3207,22 @@ void uninitvar_strpbrk(void)
     (void)strpbrk(cs,ct);
 }
 
-void uninitvar_strncat(char *Ct, char *S, size_t N)
+// char * strncat ( char * destination, const char * source, size_t num );
+void uninitvar_strncat(char *d, char *s, size_t n)
 {
-    char *ct_1, *ct_2;
-    char *s;
-    size_t n1, n2;
+    char *dest;
+    char *src;
+    size_t num;
+
     // cppcheck-suppress uninitvar
-    (void)strncat(ct_1,s,n1);
+    (void)strncat(dest,s,n);
     // cppcheck-suppress uninitvar
-    (void)strncat(ct_2,S,N);
+    (void)strncat(d,src,n);
     // cppcheck-suppress uninitvar
-    (void)strncat(Ct,s,N);
-    // cppcheck-suppress uninitvar
-    (void)strncat(Ct,S,n2);
+    (void)strncat(d,s,num);
 
     // no warning is expected for
-    (void)strncat(Ct,S,N);
+    (void)strncat(d,s,n);
 }
 
 // errno_t strcat_s(char *restrict dest, rsize_t destsz, const char *restrict src); // since C11
@@ -3210,15 +3309,14 @@ void uninitvar_strncmp(char *Ct, char *S, size_t N)
 {
     char *ct;
     char *s;
-    size_t n1, n2;
-    // cppcheck-suppress uninitvar
-    (void)strncmp(ct,s,n1);
+    size_t n1;
+
     // cppcheck-suppress uninitvar
     (void)strncmp(ct,S,N);
     // cppcheck-suppress uninitvar
     (void)strncmp(Ct,s,N);
     // cppcheck-suppress uninitvar
-    (void)strncmp(Ct,S,n2);
+    (void)strncmp(Ct,S,n1);
 
     // no warning is expected for
     (void)strncmp(Ct,S,N);
@@ -3356,12 +3454,20 @@ void uninitvar_wcscoll(void)
     (void)wcscoll(cs,ct);
 }
 
-void uninitvar_strrchr(void)
+//const char * strrchr ( const char * str, int character );
+//      char * strrchr (       char * str, int character );
+void uninitvar_strrchr(const char * s, int c)
 {
     char * str;
-    int c;
+    int character;
+
     // cppcheck-suppress uninitvar
     (void)strrchr(str,c);
+    // cppcheck-suppress uninitvar
+    (void)strrchr(s,character);
+
+    // No warning is expected for
+    (void)strrchr(s,c);
 }
 
 void uninitvar_wcsrchr(void)
@@ -3442,18 +3548,40 @@ void uninitvar_tmpnam(void)
     (void)tmpnam(s);
 }
 
-void uninitvar_tolower(void)
+void uninitvar_tolower(int character)
 {
     int c;
     // cppcheck-suppress uninitvar
     (void)tolower(c);
+
+    int *pc=&c;
+    // cppcheck-suppress uninitvar
+    (void)tolower(*pc);
+
+    // No warning is expected
+    (void)tolower(character);
+
+    int *pChar = &character;
+    // No warning is expected
+    (void)tolower(*pChar);
 }
 
-void uninitvar_toupper(void)
+void uninitvar_toupper(int character)
 {
     int c;
     // cppcheck-suppress uninitvar
     (void)toupper(c);
+
+    int *pc=&c;
+    // cppcheck-suppress uninitvar
+    (void)toupper(*pc);
+
+    // No warning is expected
+    (void)toupper(character);
+
+    int *pChar = &character;
+    // No warning is expected
+    (void)toupper(*pChar);
 }
 
 void uninitvar_wcstof(void)
@@ -3658,15 +3786,26 @@ void uninitvar_wscanf(void)
     (void)wscanf(format,&i);
 }
 
-void uninitvar_sscanf(void)
+void uninitvar_sscanf(char *s, const char *f, int i, int *ip)
 {
     char *string;
     const char * format;
-    int i;
+    int *pInteger;
+
     // cppcheck-suppress uninitvar
-    (void)sscanf(string,format);
+    (void)sscanf(string,f);
     // cppcheck-suppress uninitvar
-    (void)sscanf(string,format,&i);
+    (void)sscanf(string,f,i);
+    // cppcheck-suppress uninitvar
+    (void)sscanf(string,f,ip);
+    // cppcheck-suppress uninitvar
+    (void)sscanf(s,format,&i);
+    // cppcheck-suppress uninitvar
+    (void)sscanf(s,f,pInteger);
+
+    // No warning is expected
+    (void)sscanf(s,f,&i);
+    (void)sscanf(s,f,ip);
 }
 
 void uninitvar_fwscanf(void)
