@@ -10,6 +10,28 @@
 #include <windows.h>
 #include <direct.h>
 #include <stdlib.h>
+#include <time.h>
+
+
+void uninitvar__putenv(char * envstr)
+{
+    // No warning is expected
+    (void)_putenv(envstr);
+
+    char * p;
+    // cppcheck-suppress uninitvar
+    (void)_putenv(p);
+}
+
+void nullPointer__putenv(char * envstr)
+{
+    // No warning is expected
+    (void)_putenv(envstr);
+
+    char * p=NULL;
+    // cppcheck-suppress nullPointer
+    (void)_putenv(p);
+}
 
 void invalidFunctionArg__getcwd(char * buffer)
 {
@@ -22,6 +44,26 @@ void invalidFunctionArg__getcwd(char * buffer)
     free(buffer);
 }
 
+void nullPointer__get_timezone(long *sec)
+{
+    // No warning is expected
+    (void)_get_timezone(sec);
+
+    long *pSec = NULL;
+    // cppcheck-suppress nullPointer
+    (void)_get_timezone(pSec);
+}
+
+void nullPointer__get_daylight(int *h)
+{
+    // No warning is expected
+    (void)_get_daylight(h);
+
+    int *pHours = NULL;
+    // cppcheck-suppress nullPointer
+    (void)_get_daylight(pHours);
+}
+
 void validCode()
 {
     DWORD dwordInit = 0;
@@ -190,6 +232,11 @@ void validCode()
     void * pAlloc1 = _aligned_malloc(100, 2);
     _aligned_free(pAlloc1);
 
+    ::PostMessage(nullptr, WM_QUIT, 0, 0);
+
+    printf("%zu", __alignof(int));
+    printf("%zu", _alignof(double));
+
     // Valid Library usage, no leaks, valid arguments
     HINSTANCE hInstLib = LoadLibrary(L"My.dll");
     FreeLibrary(hInstLib);
@@ -896,6 +943,24 @@ error_t nullPointer__strncpy_s_l(char *strDest, size_t numberOfElements, const c
     return _strncpy_s_l(strDest, numberOfElements, strSource, count, locale);
 }
 
+void GetShortPathName_validCode(TCHAR* lpszPath)
+{
+    long length = GetShortPathName(lpszPath, NULL, 0);
+    if (length == 0) {
+        _tprintf(TEXT("error"));
+        return;
+    }
+    TCHAR* buffer = new TCHAR[length];
+    length = GetShortPathName(lpszPath, buffer, length);
+    if (length == 0) {
+        delete [] buffer;
+        _tprintf(TEXT("error"));
+        return;
+    }
+    _tprintf(TEXT("long name = %s short name = %s"), lpszPath, buffer);
+    delete [] buffer;
+}
+
 class MyClass :public CObject {
     DECLARE_DYNAMIC(MyClass)
     DECLARE_DYNCREATE(MyClass)
