@@ -7,6 +7,7 @@
 // No warnings about bad library configuration, unmatched suppressions, etc. exitcode=0
 //
 
+#include <wx/wx.h>
 #include <wx/app.h>
 #include <wx/log.h>
 #include <wx/filefn.h>
@@ -22,10 +23,12 @@
 #include <wx/menu.h>
 #include <wx/stattext.h>
 #include <wx/sizer.h>
+#include <wx/string.h>
 
 void validCode()
 {
     wxString str = wxGetCwd();
+    (void)str;
 
     wxLogGeneric(wxLOG_Message, "test %d", 0);
     wxLogMessage("test %s", "str");
@@ -33,6 +36,9 @@ void validCode()
     wxString translation1 = _("text");
     wxString translation2 = wxGetTranslation("text");
     wxString translation3 = wxGetTranslation("string", "domain");
+    (void)translation1;
+    (void)translation2;
+    (void)translation3;
 }
 
 #if wxUSE_GUI==1
@@ -56,20 +62,23 @@ void nullPointer(const wxString &str)
     double *doublePtr = NULL;
     // cppcheck-suppress nullPointer
     (void)str.ToDouble(doublePtr);
+    double *doublePtr1 = NULL;
     // cppcheck-suppress nullPointer
-    (void)str.ToCDouble(doublePtr);
+    (void)str.ToCDouble(doublePtr1);
 
     long * longPtr = NULL;
     // cppcheck-suppress nullPointer
     (void)str.ToLong(longPtr);
+    long * longPtr1 = NULL;
     // cppcheck-suppress nullPointer
-    (void)str.ToCLong(longPtr);
+    (void)str.ToCLong(longPtr1);
 
     unsigned long * ulongPtr = NULL;
     // cppcheck-suppress nullPointer
     (void)str.ToULong(ulongPtr);
+    unsigned long * ulongPtr1 = NULL;
     // cppcheck-suppress nullPointer
-    (void)str.ToCULong(ulongPtr);
+    (void)str.ToCULong(ulongPtr1);
 
     long long * longLongPtr = NULL;
     // cppcheck-suppress nullPointer
@@ -91,13 +100,13 @@ void nullPointer_wxSizer_Add(wxSizer &sizer, wxWindow *w)
 
 void uninitvar_wxSizer_Add(wxSizer &sizer, wxWindow *w,wxObject* userData)
 {
-    int uninit;
+    int uninit1, uninit2, uninit3;
     // cppcheck-suppress uninitvar
-    sizer.Add(w,uninit);
+    sizer.Add(w,uninit1);
     // cppcheck-suppress uninitvar
-    sizer.Add(w,4,uninit);
+    sizer.Add(w,4,uninit2);
     // cppcheck-suppress uninitvar
-    sizer.Add(w,4,2,uninit,userData);
+    sizer.Add(w,4,2,uninit3,userData);
 }
 
 void ignoredReturnValue(const wxString &s)
@@ -158,25 +167,30 @@ void uninitvar_wxStaticText(wxStaticText &s)
 
 void uninitvar_wxString_NumberConversion(const wxString &str, const int numberBase)
 {
-    int uninitInteger;
+    int uninitInteger1;
+    int uninitInteger2;
+    int uninitInteger3;
+    int uninitInteger4;
+    int uninitInteger5;
+    int uninitInteger6;
     long l;
     long long ll;
     unsigned long ul;
     unsigned long long ull;
 
     // cppcheck-suppress uninitvar
-    (void)str.ToLong(&l, uninitInteger);
+    (void)str.ToLong(&l, uninitInteger1);
     // cppcheck-suppress uninitvar
-    (void)str.ToLongLong(&ll, uninitInteger);
+    (void)str.ToLongLong(&ll, uninitInteger2);
     // cppcheck-suppress uninitvar
-    (void)str.ToULong(&ul, uninitInteger);
+    (void)str.ToULong(&ul, uninitInteger3);
     // cppcheck-suppress uninitvar
-    (void)str.ToULongLong(&ull, uninitInteger);
+    (void)str.ToULongLong(&ull, uninitInteger4);
 
     // cppcheck-suppress uninitvar
-    (void)str.ToCLong(&l, uninitInteger);
+    (void)str.ToCLong(&l, uninitInteger5);
     // cppcheck-suppress uninitvar
-    (void)str.ToCULong(&ul, uninitInteger);
+    (void)str.ToCULong(&ul, uninitInteger6);
 }
 
 void uninitvar_SetMenuBar(wxFrame * const framePtr, wxMenuBar * const menuBarPtr)
@@ -265,3 +279,37 @@ void deprecatedFunctions(wxApp &a,
     calenderCtrl.EnableYearChange(/*default=yes*/);
 #endif
 }
+
+void wxString_test1(wxString s)
+{
+    for (int i = 0; i <= s.size(); ++i) {
+        // cppcheck-suppress stlOutOfBounds
+        s[i] = 'x';
+    }
+}
+
+void wxString_test2()
+{
+    wxString s;
+    // cppcheck-suppress containerOutOfBounds
+    s[1] = 'a';
+    s.append("abc");
+    s[1] = 'B';
+    printf("%s", static_cast<const char*>(s.c_str()));
+    wxPrintf("%s", s);
+    wxPrintf("%s", s.c_str());
+    s.Clear();
+}
+
+wxString::iterator wxString_test3()
+{
+    wxString wxString1;
+    wxString wxString2;
+    // cppcheck-suppress iterators2
+    for (wxString::iterator it = wxString1.begin(); it != wxString2.end(); ++it)
+    {}
+
+    wxString::iterator it = wxString1.begin();
+    // cppcheck-suppress returnDanglingLifetime
+    return it;
+}
