@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2018 Cppcheck team.
+ * Copyright (C) 2007-2019 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ public:
 
 private:
 
-    void run() override {
+    void run() OVERRIDE {
         TEST_CASE(isint);
         TEST_CASE(isbin);
         TEST_CASE(isdec);
@@ -145,10 +145,15 @@ private:
         ASSERT_EQUALS("5.0",  MathLib::divide("25.5", "5.1"));
         ASSERT_EQUALS("7.0",  MathLib::divide("21.", "3"));
         ASSERT_EQUALS("1",    MathLib::divide("3", "2"));
-        ASSERT_THROW(MathLib::divide("123", "0"), InternalError); // throw
+        ASSERT_THROW(MathLib::divide("123", "0"), InternalError);  // decimal zero: throw
+        ASSERT_THROW(MathLib::divide("123", "00"), InternalError); // octal zero: throw
+        ASSERT_THROW(MathLib::divide("123", "0x0"), InternalError); // hex zero: throw
+        MathLib::divide("123", "0.0f"); // float zero: don't throw
+        MathLib::divide("123", "0.0"); // double zero: don't throw
+        MathLib::divide("123", "0.0L"); // long double zero: don't throw
         ASSERT_THROW(MathLib::divide("-9223372036854775808", "-1"), InternalError); // #4520 - out of range => throw
         ASSERT_EQUALS("4611686018427387904",  MathLib::divide("-9223372036854775808", "-2")); // #6679
-        MathLib::divide("123", "0.0"); // don't throw
+
 
         // Unknown action should throw exception
         ASSERT_THROW(MathLib::calculate("1","2",'j'),InternalError);
@@ -281,6 +286,7 @@ private:
         ASSERT_EQUALS((int)('\x10'), MathLib::toLongNumber("'\\x10'"));
         ASSERT_EQUALS((int)('\100'), MathLib::toLongNumber("'\\100'"));
         ASSERT_EQUALS((int)('\200'), MathLib::toLongNumber("'\\200'"));
+        ASSERT_EQUALS((int)(L'A'),   MathLib::toLongNumber("L'A'"));
 #ifdef __GNUC__
         // BEGIN Implementation-specific results
         ASSERT_EQUALS((int)('AB'),    MathLib::toLongNumber("'AB'"));
@@ -370,6 +376,7 @@ private:
         ASSERT_EQUALS_DOUBLE(0.0,    MathLib::toDoubleNumber("-0.0"),     0.000001);
         ASSERT_EQUALS_DOUBLE(0.0,    MathLib::toDoubleNumber("+0.0"),     0.000001);
         ASSERT_EQUALS_DOUBLE('0',    MathLib::toDoubleNumber("'0'"),      0.000001);
+        ASSERT_EQUALS_DOUBLE(L'0',   MathLib::toDoubleNumber("L'0'"),     0.000001);
 
         ASSERT_EQUALS_DOUBLE(192, MathLib::toDoubleNumber("0x0.3p10"), 0.000001);
         ASSERT_EQUALS_DOUBLE(5.42101e-20, MathLib::toDoubleNumber("0x1p-64"), 1e-20);
@@ -668,6 +675,7 @@ private:
         ASSERT_EQUALS(false, MathLib::isIntHex("+0x"));
         ASSERT_EQUALS(false, MathLib::isIntHex("-0x"));
         ASSERT_EQUALS(false, MathLib::isIntHex("0x"));
+        ASSERT_EQUALS(false, MathLib::isIntHex("0xl"));
         ASSERT_EQUALS(false, MathLib::isIntHex("0xx"));
         ASSERT_EQUALS(false, MathLib::isIntHex("-0175"));
         ASSERT_EQUALS(false, MathLib::isIntHex("-0_garbage_"));
@@ -698,77 +706,42 @@ private:
         ASSERT_EQUALS(false, MathLib::isIntHex(""));
     }
 
-    void isValidIntegerSuffix(void) const {
+    void isValidIntegerSuffix() const {
         // negative testing
-        std::string value = "ux";
-        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "ulx";
-        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "lx";
-        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "lux";
-        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "lll";
-        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "garbage";
-        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value.clear();
-        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "llu ";
-        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "i";
-        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "iX";
-        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "i6X";
-        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "i64X";
-        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "i64 ";
-        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "i66";
-        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix(""));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("ux"));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("ulx"));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("lx"));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("lux"));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("lll"));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("garbage"));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("llu "));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("i"));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("iX"));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("i6X"));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("i64X"));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("i64 "));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("i66"));
 
         // positive testing
-        value = "u";
-        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "ul";
-        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "ull";
-        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "l";
-        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "lu";
-        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "ll";
-        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "llu";
-        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "i64";
-        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
-
-        value = "ui64";
-        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix(value.begin(), value.end()));
+        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix("u"));
+        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix("ul"));
+        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix("ull"));
+        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix("l"));
+        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix("lu"));
+        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix("ll"));
+        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix("llu"));
+        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix("llU"));
+        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix("LLU"));
+        // Microsoft extensions:
+        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix("i64"));
+        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix("I64"));
+        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix("ui64"));
+        ASSERT_EQUALS(true, MathLib::isValidIntegerSuffix("UI64"));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("i64", false));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("I64", false));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("ui64", false));
+        ASSERT_EQUALS(false, MathLib::isValidIntegerSuffix("UI64", false));
     }
 
     void ispositive() const {
@@ -800,6 +773,7 @@ private:
         ASSERT_EQUALS(false, MathLib::isDecimalFloat("."));
         ASSERT_EQUALS(false, MathLib::isDecimalFloat("..."));
         ASSERT_EQUALS(false, MathLib::isDecimalFloat(".e"));
+        ASSERT_EQUALS(false, MathLib::isDecimalFloat(".e2"));
         ASSERT_EQUALS(false, MathLib::isDecimalFloat(".E"));
         ASSERT_EQUALS(false, MathLib::isDecimalFloat("+E."));
         ASSERT_EQUALS(false, MathLib::isDecimalFloat("+e."));
@@ -917,7 +891,7 @@ private:
         ASSERT_EQUALS("-inf.0", MathLib::divide("-3.0", "-0.0f")); // inf (#5142)
     }
 
-    void isdec(void) const {
+    void isdec() const {
         // positive testing
         ASSERT_EQUALS(true, MathLib::isDec("1"));
         ASSERT_EQUALS(true, MathLib::isDec("+1"));
@@ -932,6 +906,7 @@ private:
         ASSERT_EQUALS(false, MathLib::isDec("-x"));
         ASSERT_EQUALS(false, MathLib::isDec("+x"));
         ASSERT_EQUALS(false, MathLib::isDec("x"));
+        ASSERT_EQUALS(false, MathLib::isDec(""));
     }
 
     void isNullValue() const {
