@@ -172,6 +172,9 @@ private:
         TEST_CASE(realloc18);
         TEST_CASE(realloc19);
         TEST_CASE(realloc20);
+        TEST_CASE(realloc21);
+        TEST_CASE(realloc22);
+        TEST_CASE(realloc23);
         TEST_CASE(reallocarray1);
     }
 
@@ -380,6 +383,39 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
+    void realloc21() {
+        check("char *foo(char *bs0)\n"
+              "{\n"
+              "    char *bs = bs0;\n"
+              "    bs = realloc(bs, 100);\n"
+              "    if (bs == NULL) return bs0;\n"
+              "    return bs;\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void realloc22() {
+        check("void foo(char **bsp)\n"
+              "{\n"
+              "    char *bs = *bsp;\n"
+              "    bs = realloc(bs, 100);\n"
+              "    if (bs == NULL) return;\n"
+              "    *bsp = bs;\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void realloc23() {
+        check("void foo(struct ABC *s)\n"
+              "{\n"
+              "    uint32_t *cigar = s->cigar;\n"
+              "    if (!(cigar = realloc(cigar, 100 * sizeof(*cigar))))\n"
+              "        return;\n"
+              "    s->cigar = cigar;\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
+
     void reallocarray1() {
         check("void foo()\n"
               "{\n"
@@ -2066,7 +2102,7 @@ private:
 
     void run() OVERRIDE {
         settings.inconclusive = true;
-        settings.libraries.push_back("posix");
+        settings.libraries.emplace_back("posix");
         settings.addEnabled("warning");
 
         LOAD_LIB_2(settings.library, "std.cfg");
@@ -2171,6 +2207,16 @@ private:
               "}");
         ASSERT_EQUALS("[test.cpp:2]: (error) Allocation with calloc, memcmp doesn't release it.\n"
                       "[test.cpp:2]: (error) Allocation with strdup, memcmp doesn't release it.\n", errout.str());
+
+        check("void* f(int size) {\n"
+              "    return (void*) malloc(size);\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        check("int* f(int size) {\n"
+              "    return static_cast<int*>(malloc(size));\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
     }
 
     void missingAssignment() {
