@@ -65,6 +65,10 @@ private:
         TEST_CASE(simplifyUsing9040);
         TEST_CASE(simplifyUsing9042);
         TEST_CASE(simplifyUsing9191);
+        TEST_CASE(simplifyUsing9381);
+        TEST_CASE(simplifyUsing9385);
+        TEST_CASE(simplifyUsing9388);
+        TEST_CASE(simplifyUsing9518);
     }
 
     std::string tok(const char code[], bool simplify = true, Settings::PlatformType type = Settings::Native, bool debugwarnings = true) {
@@ -524,6 +528,108 @@ private:
         ASSERT_EQUALS(exp, tok(code, false));
     }
 
+    void simplifyUsing9381() {
+        const char code[] = "namespace ns {\n"
+                            "    class Result;\n"
+                            "    using UniqueResultPtr = std::unique_ptr<Result>;\n"
+                            "    class A {\n"
+                            "    public:\n"
+                            "        void func(UniqueResultPtr);\n"
+                            "    };\n"
+                            "    void A::func(UniqueResultPtr) {\n"
+                            "    }\n"
+                            "}";
+        const char exp[] = "namespace ns { "
+                           "class Result ; "
+                           "class A { "
+                           "public: "
+                           "void func ( std :: unique_ptr < Result > ) ; "
+                           "} ; "
+                           "void A :: func ( std :: unique_ptr < Result > ) { "
+                           "} "
+                           "}";
+
+        ASSERT_EQUALS(exp, tok(code, false));
+    }
+
+    void simplifyUsing9385() {
+        {
+            const char code[] = "class A {\n"
+                                "public:\n"
+                                "    using Foo = int;\n"
+                                "    A(Foo foo);\n"
+                                "    ~A();\n"
+                                "    void func(Foo foo);\n"
+                                "};\n"
+                                "A::A(Foo) { }\n"
+                                "A::~A() { Foo foo; }\n"
+                                "void A::func(Foo) { }";
+            const char exp[] = "class A { "
+                               "public: "
+                               "A ( int foo ) ; "
+                               "~ A ( ) ; "
+                               "void func ( int foo ) ; "
+                               "} ; "
+                               "A :: A ( int ) { } "
+                               "A :: ~ A ( ) { int foo ; } "
+                               "void A :: func ( int ) { }";
+            ASSERT_EQUALS(exp, tok(code, false));
+        }
+        {
+            const char code[] = "class A {\n"
+                                "public:\n"
+                                "    struct B {\n"
+                                "        using Foo = int;\n"
+                                "        B(Foo foo);\n"
+                                "        ~B();\n"
+                                "        void func(Foo foo);\n"
+                                "    };\n"
+                                "};\n"
+                                "A::B::B(Foo) { }\n"
+                                "A::B::~B() { Foo foo; }\n"
+                                "void A::B::func(Foo) { }";
+            const char exp[] = "class A { "
+                               "public: "
+                               "struct B { "
+                               "B ( int foo ) ; "
+                               "~ B ( ) ; "
+                               "void func ( int foo ) ; "
+                               "} ; "
+                               "} ; "
+                               "A :: B :: B ( int ) { } "
+                               "A :: B :: ~ B ( ) { int foo ; } "
+                               "void A :: B :: func ( int ) { }";
+            ASSERT_EQUALS(exp, tok(code, false));
+        }
+    }
+
+    void simplifyUsing9388() {
+        const char code[] = "class A {\n"
+                            "public:\n"
+                            "    using Type = int;\n"
+                            "    A(Type&);\n"
+                            "    Type& t_;\n"
+                            "};\n"
+                            "A::A(Type& t) : t_(t) { }";
+        const char exp[] = "class A { "
+                           "public: "
+                           "A ( int & ) ; "
+                           "int & t_ ; "
+                           "} ; "
+                           "A :: A ( int & t ) : t_ ( t ) { }";
+        ASSERT_EQUALS(exp, tok(code, false));
+    }
+
+    void simplifyUsing9518() {
+        const char code[] = "namespace a {\n"
+                            "using a = enum {};\n"
+                            "}";
+        const char exp[] = "namespace a { "
+                           "enum a { } ; "
+                           "}";
+        ASSERT_EQUALS(exp, tok(code, false));
+    }
+
 };
 
 REGISTER_TEST(TestSimplifyUsing)
