@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2018 Cppcheck team.
+ * Copyright (C) 2007-2019 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ public:
 
 private:
 
-    void run() override {
+    void run() OVERRIDE {
         TEST_CASE(suppressionsBadId1);
         TEST_CASE(suppressionsDosFormat);     // Ticket #1836
         TEST_CASE(suppressionsFileNameWithColon);    // Ticket #1919 - filename includes colon
@@ -48,6 +48,7 @@ private:
         TEST_CASE(suppressionsMultiFile);
         TEST_CASE(suppressionsPathSeparator);
         TEST_CASE(suppressionsLine0);
+        TEST_CASE(suppressionsFileComment);
 
         TEST_CASE(inlinesuppress);
         TEST_CASE(inlinesuppress_symbolname);
@@ -188,7 +189,7 @@ private:
         settings.jointSuppressionReport = true;
         if (!suppression.empty()) {
             std::string r = settings.nomsg.addSuppressionLine(suppression);
-            ASSERT_EQUALS("", r);
+            EXPECT_EQ("", r);
         }
 
         unsigned int exitCode = 0;
@@ -215,7 +216,7 @@ private:
         settings.inlineSuppressions = true;
         settings.addEnabled("information");
         if (!suppression.empty()) {
-            ASSERT_EQUALS("", settings.nomsg.addSuppressionLine(suppression));
+            EXPECT_EQ("", settings.nomsg.addSuppressionLine(suppression));
         }
         ThreadExecutor executor(files, settings, *this);
         for (std::map<std::string, std::size_t>::const_iterator i = files.begin(); i != files.end(); ++i)
@@ -411,6 +412,18 @@ private:
         ASSERT_EQUALS(true, suppressions.isSuppressed(errorMessage("syntaxError", "test.cpp", 0)));
     }
 
+    void suppressionsFileComment() {
+        std::istringstream file1("# comment\nabc");
+        Suppressions suppressions1;
+        suppressions1.parseFile(file1);
+        ASSERT_EQUALS(true, suppressions1.isSuppressed(errorMessage("abc", "test.cpp", 123)));
+
+        std::istringstream file2("// comment\nabc");
+        Suppressions suppressions2;
+        suppressions2.parseFile(file2);
+        ASSERT_EQUALS(true, suppressions2.isSuppressed(errorMessage("abc", "test.cpp", 123)));
+    }
+
     void inlinesuppress() {
         Suppressions::Suppression s;
         std::string msg;
@@ -496,7 +509,7 @@ private:
         settings.addEnabled("style");
         settings.inlineSuppressions = true;
         settings.relativePaths = true;
-        settings.basePaths.push_back("/somewhere");
+        settings.basePaths.emplace_back("/somewhere");
         const char code[] =
             "struct Point\n"
             "{\n"
@@ -509,7 +522,7 @@ private:
         ASSERT_EQUALS("",errout.str());
     }
 
-    void suppressingSyntaxErrors() { // syntaxErrors should be suppressable (#7076)
+    void suppressingSyntaxErrors() { // syntaxErrors should be suppressible (#7076)
         std::map<std::string, std::string> files;
         files["test.cpp"] = "if if\n";
 
@@ -517,7 +530,7 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
-    void suppressingSyntaxErrorsInline() { // syntaxErrors should be suppressable (#5917)
+    void suppressingSyntaxErrorsInline() { // syntaxErrors should be suppressible (#5917)
         std::map<std::string, std::string> files;
         files["test.cpp"] = "double result(0.0);\n"
                             "_asm\n"
@@ -533,7 +546,7 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
-    void suppressingSyntaxErrorsWhileFileRead() { // syntaxError while file read should be suppressable (PR #1333)
+    void suppressingSyntaxErrorsWhileFileRead() { // syntaxError while file read should be suppressible (PR #1333)
         std::map<std::string, std::string> files;
         files["test.cpp"] = "CONST (genType, KS_CONST) genService[KS_CFG_NR_OF_NVM_BLOCKS] =\n"
                             "{\n"
